# Generated by sgb2ns, created by Polly Huang
# GRAPH (#nodes #edges id uu vv ww xx yy zz):
# 1000 4096 transtub(0,3,0,0,{4,283,3,1.000,0.000,0.000},{10,142,3,0.500,0.000,0.000},{8,59,3,0.500,0.000,0.000}) 283 3 6 1 

proc create-topology {nsns node linkBW} {
	upvar $node n
	upvar $nsns ns

	set verbose 1

	if {$verbose} { 
		puts "creating nodes..." 
}
		for {set i 0} {$i < 1000} {incr i} {
			set n($i) [$ns node]
	}

	# EDGES (from-node to-node length a b):
	if {$verbose} { 
		puts -nonewline "Creating links 0..."
		flush stdout 
	}
	$ns duplex-link $n(0) $n(14) $linkBW 220ms DropTail
	$ns duplex-link $n(0) $n(4) $linkBW 740ms DropTail
	$ns duplex-link $n(0) $n(6) $linkBW 530ms DropTail
	$ns duplex-link $n(0) $n(7) $linkBW 990ms DropTail
	$ns duplex-link $n(1) $n(49) $linkBW 200ms DropTail
	$ns duplex-link $n(1) $n(43) $linkBW 510ms DropTail
	$ns duplex-link $n(1) $n(36) $linkBW 200ms DropTail
	$ns duplex-link $n(1) $n(35) $linkBW 110ms DropTail
	$ns duplex-link $n(1) $n(18) $linkBW 570ms DropTail
	$ns duplex-link $n(1) $n(2) $linkBW 410ms DropTail
	if {$verbose} { puts -nonewline "10..."; flush stdout }
	$ns duplex-link $n(2) $n(826) $linkBW 780ms DropTail
	$ns duplex-link $n(2) $n(60) $linkBW 170ms DropTail
	$ns duplex-link $n(2) $n(4) $linkBW 260ms DropTail
	$ns duplex-link $n(2) $n(6) $linkBW 460ms DropTail
	$ns duplex-link $n(2) $n(7) $linkBW 30ms DropTail
	$ns duplex-link $n(3) $n(72) $linkBW 230ms DropTail
	$ns duplex-link $n(3) $n(5) $linkBW 620ms DropTail
	$ns duplex-link $n(3) $n(7) $linkBW 530ms DropTail
	$ns duplex-link $n(3) $n(8) $linkBW 750ms DropTail
	$ns duplex-link $n(3) $n(9) $linkBW 30ms DropTail
	if {$verbose} { puts -nonewline "20..."; flush stdout }
	$ns duplex-link $n(4) $n(260) $linkBW 860ms DropTail
	$ns duplex-link $n(4) $n(111) $linkBW 90ms DropTail
	$ns duplex-link $n(4) $n(98) $linkBW 170ms DropTail
	$ns duplex-link $n(4) $n(86) $linkBW 200ms DropTail
	$ns duplex-link $n(4) $n(82) $linkBW 360ms DropTail
	$ns duplex-link $n(4) $n(74) $linkBW 210ms DropTail
	$ns duplex-link $n(4) $n(5) $linkBW 740ms DropTail
	$ns duplex-link $n(4) $n(8) $linkBW 640ms DropTail
	$ns duplex-link $n(5) $n(161) $linkBW 130ms DropTail
	$ns duplex-link $n(5) $n(153) $linkBW 190ms DropTail
	if {$verbose} { puts -nonewline "30..."; flush stdout }
	$ns duplex-link $n(5) $n(147) $linkBW 430ms DropTail
	$ns duplex-link $n(5) $n(133) $linkBW 300ms DropTail
	$ns duplex-link $n(5) $n(129) $linkBW 110ms DropTail
	$ns duplex-link $n(5) $n(115) $linkBW 260ms DropTail
	$ns duplex-link $n(5) $n(6) $linkBW 590ms DropTail
	$ns duplex-link $n(5) $n(9) $linkBW 600ms DropTail
	$ns duplex-link $n(6) $n(172) $linkBW 360ms DropTail
	$ns duplex-link $n(6) $n(162) $linkBW 430ms DropTail
	$ns duplex-link $n(6) $n(9) $linkBW 370ms DropTail
	$ns duplex-link $n(7) $n(829) $linkBW 660ms DropTail
	if {$verbose} { puts -nonewline "40..."; flush stdout }
	$ns duplex-link $n(7) $n(256) $linkBW 1100ms DropTail
	$ns duplex-link $n(7) $n(208) $linkBW 240ms DropTail
	$ns duplex-link $n(7) $n(201) $linkBW 560ms DropTail
	$ns duplex-link $n(7) $n(186) $linkBW 70ms DropTail
	$ns duplex-link $n(7) $n(178) $linkBW 170ms DropTail
	$ns duplex-link $n(7) $n(8) $linkBW 880ms DropTail
	$ns duplex-link $n(8) $n(214) $linkBW 200ms DropTail
	$ns duplex-link $n(9) $n(533) $linkBW 1200ms DropTail
	$ns duplex-link $n(9) $n(534) $linkBW 1190ms DropTail
	$ns duplex-link $n(9) $n(245) $linkBW 120ms DropTail
	if {$verbose} { puts -nonewline "50..."; flush stdout }
	$ns duplex-link $n(9) $n(237) $linkBW 350ms DropTail
	$ns duplex-link $n(9) $n(229) $linkBW 260ms DropTail
	$ns duplex-link $n(9) $n(223) $linkBW 250ms DropTail
	$ns duplex-link $n(10) $n(12) $linkBW 120ms DropTail
	$ns duplex-link $n(10) $n(13) $linkBW 320ms DropTail
	$ns duplex-link $n(10) $n(14) $linkBW 450ms DropTail
	$ns duplex-link $n(10) $n(16) $linkBW 100ms DropTail
	$ns duplex-link $n(10) $n(17) $linkBW 600ms DropTail
	$ns duplex-link $n(11) $n(17) $linkBW 520ms DropTail
	$ns duplex-link $n(12) $n(13) $linkBW 370ms DropTail
	if {$verbose} { puts -nonewline "60..."; flush stdout }
	$ns duplex-link $n(12) $n(16) $linkBW 220ms DropTail
	$ns duplex-link $n(13) $n(14) $linkBW 240ms DropTail
	$ns duplex-link $n(13) $n(16) $linkBW 280ms DropTail
	$ns duplex-link $n(14) $n(15) $linkBW 380ms DropTail
	$ns duplex-link $n(18) $n(19) $linkBW 520ms DropTail
	$ns duplex-link $n(18) $n(20) $linkBW 560ms DropTail
	$ns duplex-link $n(18) $n(21) $linkBW 240ms DropTail
	$ns duplex-link $n(18) $n(23) $linkBW 510ms DropTail
	$ns duplex-link $n(19) $n(20) $linkBW 330ms DropTail
	$ns duplex-link $n(20) $n(21) $linkBW 430ms DropTail
	if {$verbose} { puts -nonewline "70..."; flush stdout }
	$ns duplex-link $n(20) $n(22) $linkBW 350ms DropTail
	$ns duplex-link $n(20) $n(23) $linkBW 530ms DropTail
	$ns duplex-link $n(21) $n(22) $linkBW 290ms DropTail
	$ns duplex-link $n(21) $n(23) $linkBW 280ms DropTail
	$ns duplex-link $n(24) $n(25) $linkBW 530ms DropTail
	$ns duplex-link $n(24) $n(26) $linkBW 280ms DropTail
	$ns duplex-link $n(24) $n(27) $linkBW 190ms DropTail
	$ns duplex-link $n(24) $n(28) $linkBW 480ms DropTail
	$ns duplex-link $n(24) $n(30) $linkBW 20ms DropTail
	$ns duplex-link $n(24) $n(32) $linkBW 230ms DropTail
	if {$verbose} { puts -nonewline "80..."; flush stdout }
	$ns duplex-link $n(24) $n(33) $linkBW 260ms DropTail
	$ns duplex-link $n(24) $n(34) $linkBW 400ms DropTail
	$ns duplex-link $n(24) $n(35) $linkBW 160ms DropTail
	$ns duplex-link $n(25) $n(26) $linkBW 450ms DropTail
	$ns duplex-link $n(25) $n(29) $linkBW 520ms DropTail
	$ns duplex-link $n(25) $n(30) $linkBW 530ms DropTail
	$ns duplex-link $n(25) $n(32) $linkBW 450ms DropTail
	$ns duplex-link $n(25) $n(33) $linkBW 290ms DropTail
	$ns duplex-link $n(26) $n(27) $linkBW 150ms DropTail
	$ns duplex-link $n(26) $n(28) $linkBW 210ms DropTail
	if {$verbose} { puts -nonewline "90..."; flush stdout }
	$ns duplex-link $n(26) $n(29) $linkBW 230ms DropTail
	$ns duplex-link $n(26) $n(33) $linkBW 190ms DropTail
	$ns duplex-link $n(26) $n(34) $linkBW 160ms DropTail
	$ns duplex-link $n(26) $n(35) $linkBW 190ms DropTail
	$ns duplex-link $n(27) $n(29) $linkBW 350ms DropTail
	$ns duplex-link $n(27) $n(33) $linkBW 270ms DropTail
	$ns duplex-link $n(27) $n(34) $linkBW 310ms DropTail
	$ns duplex-link $n(28) $n(29) $linkBW 100ms DropTail
	$ns duplex-link $n(28) $n(30) $linkBW 470ms DropTail
	$ns duplex-link $n(28) $n(31) $linkBW 290ms DropTail
	if {$verbose} { puts -nonewline "100..."; flush stdout }
	$ns duplex-link $n(28) $n(32) $linkBW 260ms DropTail
	$ns duplex-link $n(28) $n(34) $linkBW 100ms DropTail
	$ns duplex-link $n(29) $n(30) $linkBW 500ms DropTail
	$ns duplex-link $n(29) $n(33) $linkBW 370ms DropTail
	$ns duplex-link $n(29) $n(34) $linkBW 190ms DropTail
	$ns duplex-link $n(29) $n(35) $linkBW 410ms DropTail
	$ns duplex-link $n(30) $n(34) $linkBW 390ms DropTail
	$ns duplex-link $n(30) $n(35) $linkBW 160ms DropTail
	$ns duplex-link $n(31) $n(34) $linkBW 240ms DropTail
	$ns duplex-link $n(31) $n(35) $linkBW 390ms DropTail
	if {$verbose} { puts -nonewline "110..."; flush stdout }
	$ns duplex-link $n(32) $n(33) $linkBW 180ms DropTail
	$ns duplex-link $n(32) $n(34) $linkBW 200ms DropTail
	$ns duplex-link $n(32) $n(35) $linkBW 150ms DropTail
	$ns duplex-link $n(34) $n(35) $linkBW 260ms DropTail
	$ns duplex-link $n(36) $n(40) $linkBW 220ms DropTail
	$ns duplex-link $n(36) $n(41) $linkBW 390ms DropTail
	$ns duplex-link $n(36) $n(42) $linkBW 260ms DropTail
	$ns duplex-link $n(37) $n(40) $linkBW 90ms DropTail
	$ns duplex-link $n(37) $n(41) $linkBW 360ms DropTail
	$ns duplex-link $n(38) $n(39) $linkBW 520ms DropTail
	if {$verbose} { puts -nonewline "120..."; flush stdout }
	$ns duplex-link $n(38) $n(41) $linkBW 230ms DropTail
	$ns duplex-link $n(38) $n(42) $linkBW 290ms DropTail
	$ns duplex-link $n(39) $n(40) $linkBW 270ms DropTail
	$ns duplex-link $n(39) $n(42) $linkBW 350ms DropTail
	$ns duplex-link $n(41) $n(42) $linkBW 250ms DropTail
	$ns duplex-link $n(43) $n(45) $linkBW 340ms DropTail
	$ns duplex-link $n(43) $n(47) $linkBW 440ms DropTail
	$ns duplex-link $n(44) $n(48) $linkBW 210ms DropTail
	$ns duplex-link $n(45) $n(48) $linkBW 260ms DropTail
	$ns duplex-link $n(46) $n(47) $linkBW 350ms DropTail
	if {$verbose} { puts -nonewline "130..."; flush stdout }
	$ns duplex-link $n(47) $n(48) $linkBW 430ms DropTail
	$ns duplex-link $n(49) $n(50) $linkBW 230ms DropTail
	$ns duplex-link $n(49) $n(51) $linkBW 520ms DropTail
	$ns duplex-link $n(49) $n(53) $linkBW 370ms DropTail
	$ns duplex-link $n(49) $n(57) $linkBW 160ms DropTail
	$ns duplex-link $n(50) $n(51) $linkBW 480ms DropTail
	$ns duplex-link $n(50) $n(52) $linkBW 440ms DropTail
	$ns duplex-link $n(50) $n(55) $linkBW 120ms DropTail
	$ns duplex-link $n(51) $n(53) $linkBW 450ms DropTail
	$ns duplex-link $n(51) $n(54) $linkBW 500ms DropTail
	if {$verbose} { puts -nonewline "140..."; flush stdout }
	$ns duplex-link $n(51) $n(55) $linkBW 590ms DropTail
	$ns duplex-link $n(52) $n(54) $linkBW 160ms DropTail
	$ns duplex-link $n(52) $n(55) $linkBW 450ms DropTail
	$ns duplex-link $n(52) $n(56) $linkBW 210ms DropTail
	$ns duplex-link $n(53) $n(54) $linkBW 150ms DropTail
	$ns duplex-link $n(53) $n(55) $linkBW 170ms DropTail
	$ns duplex-link $n(53) $n(57) $linkBW 340ms DropTail
	$ns duplex-link $n(54) $n(57) $linkBW 480ms DropTail
	$ns duplex-link $n(55) $n(57) $linkBW 370ms DropTail
	$ns duplex-link $n(58) $n(60) $linkBW 130ms DropTail
	if {$verbose} { puts -nonewline "150..."; flush stdout }
	$ns duplex-link $n(58) $n(63) $linkBW 230ms DropTail
	$ns duplex-link $n(58) $n(65) $linkBW 100ms DropTail
	$ns duplex-link $n(59) $n(60) $linkBW 450ms DropTail
	$ns duplex-link $n(59) $n(63) $linkBW 340ms DropTail
	$ns duplex-link $n(60) $n(61) $linkBW 200ms DropTail
	$ns duplex-link $n(60) $n(62) $linkBW 220ms DropTail
	$ns duplex-link $n(61) $n(62) $linkBW 420ms DropTail
	$ns duplex-link $n(61) $n(64) $linkBW 340ms DropTail
	$ns duplex-link $n(62) $n(63) $linkBW 190ms DropTail
	$ns duplex-link $n(62) $n(65) $linkBW 370ms DropTail
	if {$verbose} { puts -nonewline "160..."; flush stdout }
	$ns duplex-link $n(63) $n(64) $linkBW 340ms DropTail
	$ns duplex-link $n(66) $n(68) $linkBW 470ms DropTail
	$ns duplex-link $n(66) $n(70) $linkBW 210ms DropTail
	$ns duplex-link $n(66) $n(71) $linkBW 90ms DropTail
	$ns duplex-link $n(66) $n(73) $linkBW 180ms DropTail
	$ns duplex-link $n(67) $n(69) $linkBW 140ms DropTail
	$ns duplex-link $n(67) $n(70) $linkBW 410ms DropTail
	$ns duplex-link $n(68) $n(70) $linkBW 530ms DropTail
	$ns duplex-link $n(68) $n(71) $linkBW 370ms DropTail
	$ns duplex-link $n(69) $n(70) $linkBW 290ms DropTail
	if {$verbose} { puts -nonewline "170..."; flush stdout }
	$ns duplex-link $n(69) $n(71) $linkBW 250ms DropTail
	$ns duplex-link $n(69) $n(72) $linkBW 60ms DropTail
	$ns duplex-link $n(70) $n(73) $linkBW 380ms DropTail
	$ns duplex-link $n(71) $n(72) $linkBW 190ms DropTail
	$ns duplex-link $n(71) $n(73) $linkBW 160ms DropTail
	$ns duplex-link $n(72) $n(73) $linkBW 320ms DropTail
	$ns duplex-link $n(74) $n(75) $linkBW 180ms DropTail
	$ns duplex-link $n(74) $n(76) $linkBW 410ms DropTail
	$ns duplex-link $n(75) $n(76) $linkBW 300ms DropTail
	$ns duplex-link $n(77) $n(78) $linkBW 430ms DropTail
	if {$verbose} { puts -nonewline "180..."; flush stdout }
	$ns duplex-link $n(77) $n(79) $linkBW 430ms DropTail
	$ns duplex-link $n(77) $n(81) $linkBW 160ms DropTail
	$ns duplex-link $n(78) $n(82) $linkBW 510ms DropTail
	$ns duplex-link $n(79) $n(81) $linkBW 270ms DropTail
	$ns duplex-link $n(79) $n(82) $linkBW 520ms DropTail
	$ns duplex-link $n(80) $n(82) $linkBW 220ms DropTail
	$ns duplex-link $n(81) $n(82) $linkBW 260ms DropTail
	$ns duplex-link $n(83) $n(86) $linkBW 280ms DropTail
	$ns duplex-link $n(83) $n(87) $linkBW 460ms DropTail
	$ns duplex-link $n(83) $n(88) $linkBW 590ms DropTail
	if {$verbose} { puts -nonewline "190..."; flush stdout }
	$ns duplex-link $n(83) $n(90) $linkBW 170ms DropTail
	$ns duplex-link $n(83) $n(91) $linkBW 280ms DropTail
	$ns duplex-link $n(83) $n(92) $linkBW 480ms DropTail
	$ns duplex-link $n(83) $n(93) $linkBW 490ms DropTail
	$ns duplex-link $n(84) $n(85) $linkBW 320ms DropTail
	$ns duplex-link $n(84) $n(90) $linkBW 520ms DropTail
	$ns duplex-link $n(84) $n(92) $linkBW 200ms DropTail
	$ns duplex-link $n(85) $n(86) $linkBW 250ms DropTail
	$ns duplex-link $n(85) $n(87) $linkBW 190ms DropTail
	$ns duplex-link $n(85) $n(88) $linkBW 450ms DropTail
	if {$verbose} { puts -nonewline "200..."; flush stdout }
	$ns duplex-link $n(85) $n(90) $linkBW 490ms DropTail
	$ns duplex-link $n(85) $n(92) $linkBW 400ms DropTail
	$ns duplex-link $n(86) $n(87) $linkBW 360ms DropTail
	$ns duplex-link $n(86) $n(89) $linkBW 530ms DropTail
	$ns duplex-link $n(86) $n(91) $linkBW 420ms DropTail
	$ns duplex-link $n(87) $n(88) $linkBW 260ms DropTail
	$ns duplex-link $n(87) $n(89) $linkBW 420ms DropTail
	$ns duplex-link $n(87) $n(90) $linkBW 420ms DropTail
	$ns duplex-link $n(87) $n(91) $linkBW 320ms DropTail
	$ns duplex-link $n(87) $n(92) $linkBW 210ms DropTail
	if {$verbose} { puts -nonewline "210..."; flush stdout }
	$ns duplex-link $n(88) $n(89) $linkBW 370ms DropTail
	$ns duplex-link $n(88) $n(90) $linkBW 480ms DropTail
	$ns duplex-link $n(89) $n(90) $linkBW 180ms DropTail
	$ns duplex-link $n(90) $n(91) $linkBW 140ms DropTail
	$ns duplex-link $n(91) $n(92) $linkBW 230ms DropTail
	$ns duplex-link $n(91) $n(93) $linkBW 300ms DropTail
	$ns duplex-link $n(94) $n(98) $linkBW 200ms DropTail
	$ns duplex-link $n(95) $n(96) $linkBW 460ms DropTail
	$ns duplex-link $n(95) $n(97) $linkBW 300ms DropTail
	$ns duplex-link $n(95) $n(98) $linkBW 220ms DropTail
	if {$verbose} { puts -nonewline "220..."; flush stdout }
	$ns duplex-link $n(95) $n(99) $linkBW 380ms DropTail
	$ns duplex-link $n(96) $n(99) $linkBW 120ms DropTail
	$ns duplex-link $n(97) $n(98) $linkBW 150ms DropTail
	$ns duplex-link $n(97) $n(99) $linkBW 90ms DropTail
	$ns duplex-link $n(98) $n(99) $linkBW 240ms DropTail
	$ns duplex-link $n(100) $n(104) $linkBW 270ms DropTail
	$ns duplex-link $n(100) $n(105) $linkBW 150ms DropTail
	$ns duplex-link $n(100) $n(107) $linkBW 380ms DropTail
	$ns duplex-link $n(100) $n(110) $linkBW 180ms DropTail
	$ns duplex-link $n(100) $n(111) $linkBW 440ms DropTail
	if {$verbose} { puts -nonewline "230..."; flush stdout }
	$ns duplex-link $n(100) $n(112) $linkBW 200ms DropTail
	$ns duplex-link $n(101) $n(102) $linkBW 30ms DropTail
	$ns duplex-link $n(101) $n(103) $linkBW 220ms DropTail
	$ns duplex-link $n(101) $n(105) $linkBW 180ms DropTail
	$ns duplex-link $n(101) $n(108) $linkBW 280ms DropTail
	$ns duplex-link $n(101) $n(113) $linkBW 190ms DropTail
	$ns duplex-link $n(102) $n(103) $linkBW 190ms DropTail
	$ns duplex-link $n(102) $n(105) $linkBW 200ms DropTail
	$ns duplex-link $n(102) $n(107) $linkBW 270ms DropTail
	$ns duplex-link $n(102) $n(109) $linkBW 90ms DropTail
	if {$verbose} { puts -nonewline "240..."; flush stdout }
	$ns duplex-link $n(102) $n(110) $linkBW 80ms DropTail
	$ns duplex-link $n(102) $n(111) $linkBW 330ms DropTail
	$ns duplex-link $n(102) $n(112) $linkBW 220ms DropTail
	$ns duplex-link $n(102) $n(113) $linkBW 210ms DropTail
	$ns duplex-link $n(103) $n(104) $linkBW 510ms DropTail
	$ns duplex-link $n(103) $n(106) $linkBW 160ms DropTail
	$ns duplex-link $n(103) $n(107) $linkBW 80ms DropTail
	$ns duplex-link $n(103) $n(109) $linkBW 270ms DropTail
	$ns duplex-link $n(103) $n(110) $linkBW 140ms DropTail
	$ns duplex-link $n(103) $n(111) $linkBW 150ms DropTail
	if {$verbose} { puts -nonewline "250..."; flush stdout }
	$ns duplex-link $n(104) $n(106) $linkBW 430ms DropTail
	$ns duplex-link $n(104) $n(108) $linkBW 540ms DropTail
	$ns duplex-link $n(104) $n(109) $linkBW 320ms DropTail
	$ns duplex-link $n(104) $n(110) $linkBW 370ms DropTail
	$ns duplex-link $n(104) $n(112) $linkBW 460ms DropTail
	$ns duplex-link $n(105) $n(106) $linkBW 190ms DropTail
	$ns duplex-link $n(105) $n(108) $linkBW 430ms DropTail
	$ns duplex-link $n(105) $n(109) $linkBW 120ms DropTail
	$ns duplex-link $n(105) $n(110) $linkBW 280ms DropTail
	$ns duplex-link $n(106) $n(107) $linkBW 220ms DropTail
	if {$verbose} { puts -nonewline "260..."; flush stdout }
	$ns duplex-link $n(106) $n(109) $linkBW 130ms DropTail
	$ns duplex-link $n(106) $n(112) $linkBW 180ms DropTail
	$ns duplex-link $n(107) $n(108) $linkBW 90ms DropTail
	$ns duplex-link $n(107) $n(110) $linkBW 220ms DropTail
	$ns duplex-link $n(108) $n(109) $linkBW 340ms DropTail
	$ns duplex-link $n(108) $n(112) $linkBW 410ms DropTail
	$ns duplex-link $n(109) $n(110) $linkBW 170ms DropTail
	$ns duplex-link $n(110) $n(111) $linkBW 250ms DropTail
	$ns duplex-link $n(110) $n(113) $linkBW 290ms DropTail
	$ns duplex-link $n(114) $n(115) $linkBW 170ms DropTail
	if {$verbose} { puts -nonewline "270..."; flush stdout }
	$ns duplex-link $n(114) $n(116) $linkBW 200ms DropTail
	$ns duplex-link $n(114) $n(119) $linkBW 520ms DropTail
	$ns duplex-link $n(114) $n(120) $linkBW 370ms DropTail
	$ns duplex-link $n(115) $n(116) $linkBW 90ms DropTail
	$ns duplex-link $n(115) $n(119) $linkBW 480ms DropTail
	$ns duplex-link $n(115) $n(120) $linkBW 300ms DropTail
	$ns duplex-link $n(115) $n(121) $linkBW 270ms DropTail
	$ns duplex-link $n(116) $n(117) $linkBW 80ms DropTail
	$ns duplex-link $n(116) $n(119) $linkBW 380ms DropTail
	$ns duplex-link $n(116) $n(122) $linkBW 300ms DropTail
	if {$verbose} { puts -nonewline "280..."; flush stdout }
	$ns duplex-link $n(117) $n(119) $linkBW 460ms DropTail
	$ns duplex-link $n(117) $n(120) $linkBW 290ms DropTail
	$ns duplex-link $n(117) $n(122) $linkBW 360ms DropTail
	$ns duplex-link $n(118) $n(119) $linkBW 350ms DropTail
	$ns duplex-link $n(118) $n(121) $linkBW 450ms DropTail
	$ns duplex-link $n(118) $n(122) $linkBW 140ms DropTail
	$ns duplex-link $n(119) $n(121) $linkBW 690ms DropTail
	$ns duplex-link $n(120) $n(122) $linkBW 320ms DropTail
	$ns duplex-link $n(123) $n(127) $linkBW 210ms DropTail
	$ns duplex-link $n(123) $n(129) $linkBW 350ms DropTail
	if {$verbose} { puts -nonewline "290..."; flush stdout }
	$ns duplex-link $n(123) $n(130) $linkBW 480ms DropTail
	$ns duplex-link $n(124) $n(125) $linkBW 60ms DropTail
	$ns duplex-link $n(124) $n(126) $linkBW 430ms DropTail
	$ns duplex-link $n(124) $n(128) $linkBW 40ms DropTail
	$ns duplex-link $n(126) $n(128) $linkBW 410ms DropTail
	$ns duplex-link $n(126) $n(129) $linkBW 420ms DropTail
	$ns duplex-link $n(127) $n(128) $linkBW 410ms DropTail
	$ns duplex-link $n(127) $n(129) $linkBW 360ms DropTail
	$ns duplex-link $n(128) $n(129) $linkBW 220ms DropTail
	$ns duplex-link $n(131) $n(132) $linkBW 640ms DropTail
	if {$verbose} { puts -nonewline "300..."; flush stdout }
	$ns duplex-link $n(131) $n(134) $linkBW 500ms DropTail
	$ns duplex-link $n(131) $n(136) $linkBW 630ms DropTail
	$ns duplex-link $n(131) $n(137) $linkBW 420ms DropTail
	$ns duplex-link $n(131) $n(139) $linkBW 560ms DropTail
	$ns duplex-link $n(131) $n(140) $linkBW 270ms DropTail
	$ns duplex-link $n(132) $n(133) $linkBW 450ms DropTail
	$ns duplex-link $n(132) $n(137) $linkBW 340ms DropTail
	$ns duplex-link $n(132) $n(138) $linkBW 200ms DropTail
	$ns duplex-link $n(132) $n(139) $linkBW 220ms DropTail
	$ns duplex-link $n(133) $n(135) $linkBW 500ms DropTail
	if {$verbose} { puts -nonewline "310..."; flush stdout }
	$ns duplex-link $n(133) $n(137) $linkBW 480ms DropTail
	$ns duplex-link $n(134) $n(137) $linkBW 260ms DropTail
	$ns duplex-link $n(134) $n(140) $linkBW 310ms DropTail
	$ns duplex-link $n(135) $n(139) $linkBW 240ms DropTail
	$ns duplex-link $n(136) $n(137) $linkBW 260ms DropTail
	$ns duplex-link $n(136) $n(139) $linkBW 110ms DropTail
	$ns duplex-link $n(137) $n(139) $linkBW 160ms DropTail
	$ns duplex-link $n(138) $n(139) $linkBW 30ms DropTail
	$ns duplex-link $n(138) $n(140) $linkBW 450ms DropTail
	$ns duplex-link $n(139) $n(140) $linkBW 480ms DropTail
	if {$verbose} { puts -nonewline "320..."; flush stdout }
	$ns duplex-link $n(141) $n(142) $linkBW 150ms DropTail
	$ns duplex-link $n(141) $n(144) $linkBW 280ms DropTail
	$ns duplex-link $n(141) $n(147) $linkBW 350ms DropTail
	$ns duplex-link $n(141) $n(148) $linkBW 330ms DropTail
	$ns duplex-link $n(141) $n(149) $linkBW 100ms DropTail
	$ns duplex-link $n(142) $n(143) $linkBW 230ms DropTail
	$ns duplex-link $n(142) $n(148) $linkBW 210ms DropTail
	$ns duplex-link $n(142) $n(150) $linkBW 380ms DropTail
	$ns duplex-link $n(143) $n(145) $linkBW 510ms DropTail
	$ns duplex-link $n(143) $n(146) $linkBW 290ms DropTail
	if {$verbose} { puts -nonewline "330..."; flush stdout }
	$ns duplex-link $n(143) $n(149) $linkBW 400ms DropTail
	$ns duplex-link $n(143) $n(150) $linkBW 300ms DropTail
	$ns duplex-link $n(144) $n(146) $linkBW 520ms DropTail
	$ns duplex-link $n(144) $n(147) $linkBW 590ms DropTail
	$ns duplex-link $n(145) $n(146) $linkBW 340ms DropTail
	$ns duplex-link $n(145) $n(147) $linkBW 320ms DropTail
	$ns duplex-link $n(145) $n(149) $linkBW 110ms DropTail
	$ns duplex-link $n(146) $n(148) $linkBW 260ms DropTail
	$ns duplex-link $n(147) $n(148) $linkBW 360ms DropTail
	$ns duplex-link $n(147) $n(149) $linkBW 290ms DropTail
	if {$verbose} { puts -nonewline "340..."; flush stdout }
	$ns duplex-link $n(147) $n(150) $linkBW 130ms DropTail
	$ns duplex-link $n(149) $n(150) $linkBW 350ms DropTail
	$ns duplex-link $n(151) $n(152) $linkBW 460ms DropTail
	$ns duplex-link $n(152) $n(154) $linkBW 310ms DropTail
	$ns duplex-link $n(153) $n(154) $linkBW 290ms DropTail
	$ns duplex-link $n(155) $n(158) $linkBW 160ms DropTail
	$ns duplex-link $n(155) $n(159) $linkBW 280ms DropTail
	$ns duplex-link $n(156) $n(157) $linkBW 260ms DropTail
	$ns duplex-link $n(156) $n(158) $linkBW 340ms DropTail
	$ns duplex-link $n(156) $n(159) $linkBW 440ms DropTail
	if {$verbose} { puts -nonewline "350..."; flush stdout }
	$ns duplex-link $n(156) $n(160) $linkBW 190ms DropTail
	$ns duplex-link $n(156) $n(161) $linkBW 260ms DropTail
	$ns duplex-link $n(157) $n(159) $linkBW 480ms DropTail
	$ns duplex-link $n(158) $n(159) $linkBW 350ms DropTail
	$ns duplex-link $n(158) $n(160) $linkBW 160ms DropTail
	$ns duplex-link $n(160) $n(161) $linkBW 120ms DropTail
	$ns duplex-link $n(162) $n(163) $linkBW 330ms DropTail
	$ns duplex-link $n(162) $n(164) $linkBW 540ms DropTail
	$ns duplex-link $n(162) $n(165) $linkBW 130ms DropTail
	$ns duplex-link $n(162) $n(166) $linkBW 270ms DropTail
	if {$verbose} { puts -nonewline "360..."; flush stdout }
	$ns duplex-link $n(162) $n(167) $linkBW 240ms DropTail
	$ns duplex-link $n(162) $n(169) $linkBW 560ms DropTail
	$ns duplex-link $n(162) $n(170) $linkBW 460ms DropTail
	$ns duplex-link $n(162) $n(171) $linkBW 480ms DropTail
	$ns duplex-link $n(163) $n(164) $linkBW 400ms DropTail
	$ns duplex-link $n(163) $n(165) $linkBW 200ms DropTail
	$ns duplex-link $n(163) $n(167) $linkBW 150ms DropTail
	$ns duplex-link $n(163) $n(170) $linkBW 320ms DropTail
	$ns duplex-link $n(163) $n(171) $linkBW 360ms DropTail
	$ns duplex-link $n(164) $n(166) $linkBW 450ms DropTail
	if {$verbose} { puts -nonewline "370..."; flush stdout }
	$ns duplex-link $n(164) $n(167) $linkBW 330ms DropTail
	$ns duplex-link $n(164) $n(168) $linkBW 380ms DropTail
	$ns duplex-link $n(164) $n(169) $linkBW 490ms DropTail
	$ns duplex-link $n(164) $n(170) $linkBW 90ms DropTail
	$ns duplex-link $n(164) $n(171) $linkBW 60ms DropTail
	$ns duplex-link $n(165) $n(166) $linkBW 320ms DropTail
	$ns duplex-link $n(165) $n(167) $linkBW 130ms DropTail
	$ns duplex-link $n(165) $n(169) $linkBW 430ms DropTail
	$ns duplex-link $n(165) $n(170) $linkBW 360ms DropTail
	$ns duplex-link $n(165) $n(171) $linkBW 390ms DropTail
	if {$verbose} { puts -nonewline "380..."; flush stdout }
	$ns duplex-link $n(166) $n(167) $linkBW 330ms DropTail
	$ns duplex-link $n(166) $n(170) $linkBW 400ms DropTail
	$ns duplex-link $n(166) $n(171) $linkBW 400ms DropTail
	$ns duplex-link $n(167) $n(169) $linkBW 370ms DropTail
	$ns duplex-link $n(168) $n(171) $linkBW 360ms DropTail
	$ns duplex-link $n(170) $n(171) $linkBW 40ms DropTail
	$ns duplex-link $n(172) $n(173) $linkBW 330ms DropTail
	$ns duplex-link $n(172) $n(174) $linkBW 390ms DropTail
	$ns duplex-link $n(172) $n(175) $linkBW 100ms DropTail
	$ns duplex-link $n(172) $n(177) $linkBW 350ms DropTail
	if {$verbose} { puts -nonewline "390..."; flush stdout }
	$ns duplex-link $n(173) $n(175) $linkBW 280ms DropTail
	$ns duplex-link $n(173) $n(177) $linkBW 60ms DropTail
	$ns duplex-link $n(174) $n(177) $linkBW 490ms DropTail
	$ns duplex-link $n(175) $n(176) $linkBW 300ms DropTail
	$ns duplex-link $n(178) $n(180) $linkBW 180ms DropTail
	$ns duplex-link $n(178) $n(182) $linkBW 470ms DropTail
	$ns duplex-link $n(179) $n(181) $linkBW 220ms DropTail
	$ns duplex-link $n(180) $n(183) $linkBW 290ms DropTail
	$ns duplex-link $n(181) $n(183) $linkBW 650ms DropTail
	$ns duplex-link $n(182) $n(184) $linkBW 480ms DropTail
	if {$verbose} { puts -nonewline "400..."; flush stdout }
	$ns duplex-link $n(185) $n(186) $linkBW 110ms DropTail
	$ns duplex-link $n(185) $n(187) $linkBW 210ms DropTail
	$ns duplex-link $n(185) $n(188) $linkBW 260ms DropTail
	$ns duplex-link $n(186) $n(187) $linkBW 90ms DropTail
	$ns duplex-link $n(186) $n(191) $linkBW 140ms DropTail
	$ns duplex-link $n(187) $n(189) $linkBW 130ms DropTail
	$ns duplex-link $n(187) $n(190) $linkBW 330ms DropTail
	$ns duplex-link $n(187) $n(191) $linkBW 60ms DropTail
	$ns duplex-link $n(188) $n(190) $linkBW 200ms DropTail
	$ns duplex-link $n(190) $n(191) $linkBW 280ms DropTail
	if {$verbose} { puts -nonewline "410..."; flush stdout }
	$ns duplex-link $n(192) $n(196) $linkBW 430ms DropTail
	$ns duplex-link $n(192) $n(197) $linkBW 240ms DropTail
	$ns duplex-link $n(192) $n(200) $linkBW 510ms DropTail
	$ns duplex-link $n(192) $n(201) $linkBW 250ms DropTail
	$ns duplex-link $n(193) $n(194) $linkBW 250ms DropTail
	$ns duplex-link $n(193) $n(195) $linkBW 220ms DropTail
	$ns duplex-link $n(193) $n(196) $linkBW 180ms DropTail
	$ns duplex-link $n(193) $n(198) $linkBW 300ms DropTail
	$ns duplex-link $n(193) $n(199) $linkBW 90ms DropTail
	$ns duplex-link $n(193) $n(201) $linkBW 290ms DropTail
	if {$verbose} { puts -nonewline "420..."; flush stdout }
	$ns duplex-link $n(194) $n(195) $linkBW 320ms DropTail
	$ns duplex-link $n(194) $n(196) $linkBW 390ms DropTail
	$ns duplex-link $n(194) $n(198) $linkBW 70ms DropTail
	$ns duplex-link $n(194) $n(199) $linkBW 210ms DropTail
	$ns duplex-link $n(194) $n(200) $linkBW 440ms DropTail
	$ns duplex-link $n(194) $n(201) $linkBW 250ms DropTail
	$ns duplex-link $n(195) $n(200) $linkBW 190ms DropTail
	$ns duplex-link $n(195) $n(201) $linkBW 480ms DropTail
	$ns duplex-link $n(196) $n(197) $linkBW 190ms DropTail
	$ns duplex-link $n(196) $n(198) $linkBW 450ms DropTail
	if {$verbose} { puts -nonewline "430..."; flush stdout }
	$ns duplex-link $n(196) $n(201) $linkBW 300ms DropTail
	$ns duplex-link $n(197) $n(198) $linkBW 260ms DropTail
	$ns duplex-link $n(197) $n(201) $linkBW 170ms DropTail
	$ns duplex-link $n(198) $n(200) $linkBW 470ms DropTail
	$ns duplex-link $n(199) $n(201) $linkBW 200ms DropTail
	$ns duplex-link $n(200) $n(201) $linkBW 520ms DropTail
	$ns duplex-link $n(202) $n(204) $linkBW 150ms DropTail
	$ns duplex-link $n(202) $n(208) $linkBW 210ms DropTail
	$ns duplex-link $n(202) $n(209) $linkBW 300ms DropTail
	$ns duplex-link $n(203) $n(205) $linkBW 670ms DropTail
	if {$verbose} { puts -nonewline "440..."; flush stdout }
	$ns duplex-link $n(203) $n(206) $linkBW 380ms DropTail
	$ns duplex-link $n(203) $n(207) $linkBW 510ms DropTail
	$ns duplex-link $n(204) $n(205) $linkBW 260ms DropTail
	$ns duplex-link $n(204) $n(206) $linkBW 390ms DropTail
	$ns duplex-link $n(204) $n(209) $linkBW 300ms DropTail
	$ns duplex-link $n(205) $n(206) $linkBW 410ms DropTail
	$ns duplex-link $n(205) $n(207) $linkBW 160ms DropTail
	$ns duplex-link $n(205) $n(208) $linkBW 180ms DropTail
	$ns duplex-link $n(205) $n(209) $linkBW 250ms DropTail
	$ns duplex-link $n(207) $n(208) $linkBW 70ms DropTail
	if {$verbose} { puts -nonewline "450..."; flush stdout }
	$ns duplex-link $n(207) $n(209) $linkBW 160ms DropTail
	$ns duplex-link $n(208) $n(209) $linkBW 90ms DropTail
	$ns duplex-link $n(210) $n(214) $linkBW 260ms DropTail
	$ns duplex-link $n(210) $n(215) $linkBW 80ms DropTail
	$ns duplex-link $n(210) $n(216) $linkBW 390ms DropTail
	$ns duplex-link $n(210) $n(217) $linkBW 270ms DropTail
	$ns duplex-link $n(211) $n(212) $linkBW 320ms DropTail
	$ns duplex-link $n(211) $n(214) $linkBW 330ms DropTail
	$ns duplex-link $n(211) $n(215) $linkBW 190ms DropTail
	$ns duplex-link $n(211) $n(216) $linkBW 320ms DropTail
	if {$verbose} { puts -nonewline "460..."; flush stdout }
	$ns duplex-link $n(212) $n(216) $linkBW 490ms DropTail
	$ns duplex-link $n(213) $n(214) $linkBW 490ms DropTail
	$ns duplex-link $n(218) $n(219) $linkBW 270ms DropTail
	$ns duplex-link $n(218) $n(220) $linkBW 130ms DropTail
	$ns duplex-link $n(218) $n(221) $linkBW 230ms DropTail
	$ns duplex-link $n(218) $n(224) $linkBW 250ms DropTail
	$ns duplex-link $n(219) $n(224) $linkBW 520ms DropTail
	$ns duplex-link $n(220) $n(224) $linkBW 320ms DropTail
	$ns duplex-link $n(221) $n(224) $linkBW 230ms DropTail
	$ns duplex-link $n(222) $n(223) $linkBW 370ms DropTail
	if {$verbose} { puts -nonewline "470..."; flush stdout }
	$ns duplex-link $n(222) $n(224) $linkBW 220ms DropTail
	$ns duplex-link $n(225) $n(226) $linkBW 510ms DropTail
	$ns duplex-link $n(225) $n(227) $linkBW 290ms DropTail
	$ns duplex-link $n(225) $n(228) $linkBW 150ms DropTail
	$ns duplex-link $n(225) $n(230) $linkBW 390ms DropTail
	$ns duplex-link $n(225) $n(231) $linkBW 520ms DropTail
	$ns duplex-link $n(226) $n(230) $linkBW 430ms DropTail
	$ns duplex-link $n(226) $n(231) $linkBW 370ms DropTail
	$ns duplex-link $n(227) $n(229) $linkBW 180ms DropTail
	$ns duplex-link $n(227) $n(231) $linkBW 330ms DropTail
	if {$verbose} { puts -nonewline "480..."; flush stdout }
	$ns duplex-link $n(227) $n(232) $linkBW 60ms DropTail
	$ns duplex-link $n(228) $n(229) $linkBW 460ms DropTail
	$ns duplex-link $n(228) $n(230) $linkBW 340ms DropTail
	$ns duplex-link $n(230) $n(231) $linkBW 170ms DropTail
	$ns duplex-link $n(230) $n(232) $linkBW 340ms DropTail
	$ns duplex-link $n(231) $n(232) $linkBW 390ms DropTail
	$ns duplex-link $n(233) $n(235) $linkBW 650ms DropTail
	$ns duplex-link $n(233) $n(237) $linkBW 310ms DropTail
	$ns duplex-link $n(233) $n(239) $linkBW 320ms DropTail
	$ns duplex-link $n(233) $n(240) $linkBW 70ms DropTail
	if {$verbose} { puts -nonewline "490..."; flush stdout }
	$ns duplex-link $n(234) $n(238) $linkBW 210ms DropTail
	$ns duplex-link $n(234) $n(239) $linkBW 200ms DropTail
	$ns duplex-link $n(234) $n(240) $linkBW 440ms DropTail
	$ns duplex-link $n(234) $n(241) $linkBW 450ms DropTail
	$ns duplex-link $n(235) $n(237) $linkBW 490ms DropTail
	$ns duplex-link $n(235) $n(239) $linkBW 420ms DropTail
	$ns duplex-link $n(236) $n(239) $linkBW 90ms DropTail
	$ns duplex-link $n(236) $n(241) $linkBW 430ms DropTail
	$ns duplex-link $n(237) $n(239) $linkBW 420ms DropTail
	$ns duplex-link $n(237) $n(240) $linkBW 320ms DropTail
	if {$verbose} { puts -nonewline "500..."; flush stdout }
	$ns duplex-link $n(238) $n(239) $linkBW 300ms DropTail
	$ns duplex-link $n(238) $n(240) $linkBW 460ms DropTail
	$ns duplex-link $n(238) $n(241) $linkBW 330ms DropTail
	$ns duplex-link $n(239) $n(240) $linkBW 250ms DropTail
	$ns duplex-link $n(239) $n(241) $linkBW 380ms DropTail
	$ns duplex-link $n(240) $n(241) $linkBW 310ms DropTail
	$ns duplex-link $n(242) $n(243) $linkBW 540ms DropTail
	$ns duplex-link $n(242) $n(244) $linkBW 350ms DropTail
	$ns duplex-link $n(242) $n(245) $linkBW 430ms DropTail
	$ns duplex-link $n(243) $n(244) $linkBW 300ms DropTail
	if {$verbose} { puts -nonewline "510..."; flush stdout }
	$ns duplex-link $n(243) $n(245) $linkBW 150ms DropTail
	$ns duplex-link $n(243) $n(246) $linkBW 590ms DropTail
	$ns duplex-link $n(243) $n(247) $linkBW 520ms DropTail
	$ns duplex-link $n(243) $n(249) $linkBW 410ms DropTail
	$ns duplex-link $n(244) $n(245) $linkBW 150ms DropTail
	$ns duplex-link $n(244) $n(246) $linkBW 350ms DropTail
	$ns duplex-link $n(245) $n(248) $linkBW 120ms DropTail
	$ns duplex-link $n(245) $n(249) $linkBW 260ms DropTail
	$ns duplex-link $n(246) $n(247) $linkBW 290ms DropTail
	$ns duplex-link $n(247) $n(249) $linkBW 380ms DropTail
	if {$verbose} { puts -nonewline "520..."; flush stdout }
	$ns duplex-link $n(248) $n(249) $linkBW 380ms DropTail
	$ns duplex-link $n(250) $n(290) $linkBW 210ms DropTail
	$ns duplex-link $n(250) $n(277) $linkBW 440ms DropTail
	$ns duplex-link $n(250) $n(272) $linkBW 500ms DropTail
	$ns duplex-link $n(250) $n(266) $linkBW 340ms DropTail
	$ns duplex-link $n(250) $n(251) $linkBW 330ms DropTail
	$ns duplex-link $n(250) $n(253) $linkBW 440ms DropTail
	$ns duplex-link $n(250) $n(256) $linkBW 560ms DropTail
	$ns duplex-link $n(251) $n(536) $linkBW 1140ms DropTail
	$ns duplex-link $n(251) $n(827) $linkBW 1610ms DropTail
	if {$verbose} { puts -nonewline "530..."; flush stdout }
	$ns duplex-link $n(251) $n(314) $linkBW 310ms DropTail
	$ns duplex-link $n(251) $n(313) $linkBW 530ms DropTail
	$ns duplex-link $n(251) $n(305) $linkBW 160ms DropTail
	$ns duplex-link $n(251) $n(299) $linkBW 220ms DropTail
	$ns duplex-link $n(251) $n(252) $linkBW 480ms DropTail
	$ns duplex-link $n(251) $n(254) $linkBW 30ms DropTail
	$ns duplex-link $n(251) $n(255) $linkBW 340ms DropTail
	$ns duplex-link $n(251) $n(259) $linkBW 270ms DropTail
	$ns duplex-link $n(251) $n(260) $linkBW 310ms DropTail
	$ns duplex-link $n(252) $n(346) $linkBW 650ms DropTail
	if {$verbose} { puts -nonewline "540..."; flush stdout }
	$ns duplex-link $n(252) $n(340) $linkBW 480ms DropTail
	$ns duplex-link $n(252) $n(327) $linkBW 310ms DropTail
	$ns duplex-link $n(252) $n(253) $linkBW 330ms DropTail
	$ns duplex-link $n(252) $n(255) $linkBW 360ms DropTail
	$ns duplex-link $n(252) $n(258) $linkBW 360ms DropTail
	$ns duplex-link $n(253) $n(356) $linkBW 570ms DropTail
	$ns duplex-link $n(253) $n(354) $linkBW 130ms DropTail
	$ns duplex-link $n(253) $n(256) $linkBW 160ms DropTail
	$ns duplex-link $n(254) $n(529) $linkBW 1410ms DropTail
	$ns duplex-link $n(254) $n(393) $linkBW 380ms DropTail
	if {$verbose} { puts -nonewline "550..."; flush stdout }
	$ns duplex-link $n(254) $n(384) $linkBW 380ms DropTail
	$ns duplex-link $n(254) $n(375) $linkBW 110ms DropTail
	$ns duplex-link $n(254) $n(372) $linkBW 500ms DropTail
	$ns duplex-link $n(254) $n(255) $linkBW 330ms DropTail
	$ns duplex-link $n(254) $n(256) $linkBW 340ms DropTail
	$ns duplex-link $n(254) $n(258) $linkBW 380ms DropTail
	$ns duplex-link $n(255) $n(831) $linkBW 1360ms DropTail
	$ns duplex-link $n(255) $n(436) $linkBW 240ms DropTail
	$ns duplex-link $n(255) $n(431) $linkBW 190ms DropTail
	$ns duplex-link $n(255) $n(423) $linkBW 210ms DropTail
	if {$verbose} { puts -nonewline "560..."; flush stdout }
	$ns duplex-link $n(255) $n(417) $linkBW 260ms DropTail
	$ns duplex-link $n(255) $n(411) $linkBW 310ms DropTail
	$ns duplex-link $n(255) $n(401) $linkBW 50ms DropTail
	$ns duplex-link $n(255) $n(258) $linkBW 550ms DropTail
	$ns duplex-link $n(255) $n(260) $linkBW 400ms DropTail
	$ns duplex-link $n(256) $n(468) $linkBW 460ms DropTail
	$ns duplex-link $n(256) $n(456) $linkBW 470ms DropTail
	$ns duplex-link $n(256) $n(448) $linkBW 220ms DropTail
	$ns duplex-link $n(256) $n(257) $linkBW 370ms DropTail
	$ns duplex-link $n(256) $n(259) $linkBW 100ms DropTail
	if {$verbose} { puts -nonewline "570..."; flush stdout }
	$ns duplex-link $n(256) $n(260) $linkBW 70ms DropTail
	$ns duplex-link $n(257) $n(491) $linkBW 140ms DropTail
	$ns duplex-link $n(257) $n(480) $linkBW 230ms DropTail
	$ns duplex-link $n(257) $n(474) $linkBW 160ms DropTail
	$ns duplex-link $n(257) $n(258) $linkBW 420ms DropTail
	$ns duplex-link $n(257) $n(259) $linkBW 280ms DropTail
	$ns duplex-link $n(257) $n(260) $linkBW 310ms DropTail
	$ns duplex-link $n(258) $n(501) $linkBW 460ms DropTail
	$ns duplex-link $n(258) $n(496) $linkBW 530ms DropTail
	$ns duplex-link $n(258) $n(259) $linkBW 140ms DropTail
	if {$verbose} { puts -nonewline "580..."; flush stdout }
	$ns duplex-link $n(259) $n(516) $linkBW 540ms DropTail
	$ns duplex-link $n(260) $n(520) $linkBW 320ms DropTail
	$ns duplex-link $n(261) $n(263) $linkBW 210ms DropTail
	$ns duplex-link $n(261) $n(267) $linkBW 170ms DropTail
	$ns duplex-link $n(261) $n(268) $linkBW 120ms DropTail
	$ns duplex-link $n(262) $n(265) $linkBW 480ms DropTail
	$ns duplex-link $n(263) $n(265) $linkBW 400ms DropTail
	$ns duplex-link $n(263) $n(266) $linkBW 420ms DropTail
	$ns duplex-link $n(264) $n(267) $linkBW 270ms DropTail
	$ns duplex-link $n(265) $n(266) $linkBW 30ms DropTail
	if {$verbose} { puts -nonewline "590..."; flush stdout }
	$ns duplex-link $n(265) $n(267) $linkBW 390ms DropTail
	$ns duplex-link $n(266) $n(267) $linkBW 410ms DropTail
	$ns duplex-link $n(266) $n(268) $linkBW 180ms DropTail
	$ns duplex-link $n(269) $n(270) $linkBW 320ms DropTail
	$ns duplex-link $n(269) $n(271) $linkBW 260ms DropTail
	$ns duplex-link $n(269) $n(275) $linkBW 370ms DropTail
	$ns duplex-link $n(271) $n(272) $linkBW 440ms DropTail
	$ns duplex-link $n(271) $n(274) $linkBW 310ms DropTail
	$ns duplex-link $n(272) $n(273) $linkBW 590ms DropTail
	$ns duplex-link $n(272) $n(275) $linkBW 460ms DropTail
	if {$verbose} { puts -nonewline "600..."; flush stdout }
	$ns duplex-link $n(273) $n(274) $linkBW 280ms DropTail
	$ns duplex-link $n(276) $n(280) $linkBW 270ms DropTail
	$ns duplex-link $n(276) $n(281) $linkBW 530ms DropTail
	$ns duplex-link $n(276) $n(282) $linkBW 530ms DropTail
	$ns duplex-link $n(276) $n(285) $linkBW 380ms DropTail
	$ns duplex-link $n(277) $n(278) $linkBW 330ms DropTail
	$ns duplex-link $n(277) $n(279) $linkBW 260ms DropTail
	$ns duplex-link $n(277) $n(280) $linkBW 170ms DropTail
	$ns duplex-link $n(277) $n(281) $linkBW 420ms DropTail
	$ns duplex-link $n(277) $n(284) $linkBW 40ms DropTail
	if {$verbose} { puts -nonewline "610..."; flush stdout }
	$ns duplex-link $n(278) $n(280) $linkBW 200ms DropTail
	$ns duplex-link $n(278) $n(281) $linkBW 80ms DropTail
	$ns duplex-link $n(278) $n(284) $linkBW 340ms DropTail
	$ns duplex-link $n(278) $n(285) $linkBW 210ms DropTail
	$ns duplex-link $n(279) $n(282) $linkBW 280ms DropTail
	$ns duplex-link $n(279) $n(283) $linkBW 270ms DropTail
	$ns duplex-link $n(279) $n(285) $linkBW 230ms DropTail
	$ns duplex-link $n(280) $n(282) $linkBW 350ms DropTail
	$ns duplex-link $n(280) $n(284) $linkBW 160ms DropTail
	$ns duplex-link $n(281) $n(282) $linkBW 180ms DropTail
	if {$verbose} { puts -nonewline "620..."; flush stdout }
	$ns duplex-link $n(286) $n(289) $linkBW 320ms DropTail
	$ns duplex-link $n(286) $n(291) $linkBW 410ms DropTail
	$ns duplex-link $n(286) $n(292) $linkBW 230ms DropTail
	$ns duplex-link $n(287) $n(288) $linkBW 250ms DropTail
	$ns duplex-link $n(287) $n(289) $linkBW 180ms DropTail
	$ns duplex-link $n(287) $n(291) $linkBW 360ms DropTail
	$ns duplex-link $n(287) $n(292) $linkBW 60ms DropTail
	$ns duplex-link $n(288) $n(290) $linkBW 380ms DropTail
	$ns duplex-link $n(289) $n(291) $linkBW 540ms DropTail
	$ns duplex-link $n(290) $n(291) $linkBW 200ms DropTail
	if {$verbose} { puts -nonewline "630..."; flush stdout }
	$ns duplex-link $n(293) $n(294) $linkBW 320ms DropTail
	$ns duplex-link $n(293) $n(295) $linkBW 500ms DropTail
	$ns duplex-link $n(294) $n(297) $linkBW 430ms DropTail
	$ns duplex-link $n(294) $n(298) $linkBW 530ms DropTail
	$ns duplex-link $n(295) $n(297) $linkBW 170ms DropTail
	$ns duplex-link $n(295) $n(299) $linkBW 410ms DropTail
	$ns duplex-link $n(296) $n(298) $linkBW 310ms DropTail
	$ns duplex-link $n(296) $n(299) $linkBW 540ms DropTail
	$ns duplex-link $n(297) $n(298) $linkBW 210ms DropTail
	$ns duplex-link $n(297) $n(299) $linkBW 560ms DropTail
	if {$verbose} { puts -nonewline "640..."; flush stdout }
	$ns duplex-link $n(298) $n(299) $linkBW 430ms DropTail
	$ns duplex-link $n(300) $n(305) $linkBW 210ms DropTail
	$ns duplex-link $n(301) $n(302) $linkBW 320ms DropTail
	$ns duplex-link $n(301) $n(304) $linkBW 240ms DropTail
	$ns duplex-link $n(301) $n(305) $linkBW 350ms DropTail
	$ns duplex-link $n(302) $n(303) $linkBW 180ms DropTail
	$ns duplex-link $n(302) $n(304) $linkBW 200ms DropTail
	$ns duplex-link $n(302) $n(305) $linkBW 40ms DropTail
	$ns duplex-link $n(302) $n(306) $linkBW 430ms DropTail
	$ns duplex-link $n(303) $n(304) $linkBW 110ms DropTail
	if {$verbose} { puts -nonewline "650..."; flush stdout }
	$ns duplex-link $n(303) $n(305) $linkBW 190ms DropTail
	$ns duplex-link $n(304) $n(306) $linkBW 280ms DropTail
	$ns duplex-link $n(307) $n(308) $linkBW 550ms DropTail
	$ns duplex-link $n(307) $n(309) $linkBW 250ms DropTail
	$ns duplex-link $n(307) $n(310) $linkBW 410ms DropTail
	$ns duplex-link $n(307) $n(313) $linkBW 370ms DropTail
	$ns duplex-link $n(308) $n(313) $linkBW 740ms DropTail
	$ns duplex-link $n(309) $n(310) $linkBW 250ms DropTail
	$ns duplex-link $n(309) $n(312) $linkBW 220ms DropTail
	$ns duplex-link $n(309) $n(313) $linkBW 420ms DropTail
	if {$verbose} { puts -nonewline "660..."; flush stdout }
	$ns duplex-link $n(310) $n(311) $linkBW 320ms DropTail
	$ns duplex-link $n(311) $n(312) $linkBW 330ms DropTail
	$ns duplex-link $n(314) $n(315) $linkBW 450ms DropTail
	$ns duplex-link $n(314) $n(316) $linkBW 270ms DropTail
	$ns duplex-link $n(314) $n(319) $linkBW 270ms DropTail
	$ns duplex-link $n(314) $n(320) $linkBW 190ms DropTail
	$ns duplex-link $n(314) $n(321) $linkBW 310ms DropTail
	$ns duplex-link $n(314) $n(323) $linkBW 170ms DropTail
	$ns duplex-link $n(314) $n(324) $linkBW 380ms DropTail
	$ns duplex-link $n(315) $n(317) $linkBW 110ms DropTail
	if {$verbose} { puts -nonewline "670..."; flush stdout }
	$ns duplex-link $n(315) $n(320) $linkBW 340ms DropTail
	$ns duplex-link $n(315) $n(324) $linkBW 220ms DropTail
	$ns duplex-link $n(316) $n(317) $linkBW 100ms DropTail
	$ns duplex-link $n(316) $n(322) $linkBW 380ms DropTail
	$ns duplex-link $n(316) $n(323) $linkBW 110ms DropTail
	$ns duplex-link $n(317) $n(318) $linkBW 310ms DropTail
	$ns duplex-link $n(317) $n(319) $linkBW 450ms DropTail
	$ns duplex-link $n(317) $n(322) $linkBW 420ms DropTail
	$ns duplex-link $n(317) $n(323) $linkBW 190ms DropTail
	$ns duplex-link $n(317) $n(324) $linkBW 120ms DropTail
	if {$verbose} { puts -nonewline "680..."; flush stdout }
	$ns duplex-link $n(318) $n(321) $linkBW 20ms DropTail
	$ns duplex-link $n(318) $n(322) $linkBW 540ms DropTail
	$ns duplex-link $n(318) $n(323) $linkBW 260ms DropTail
	$ns duplex-link $n(318) $n(324) $linkBW 220ms DropTail
	$ns duplex-link $n(319) $n(321) $linkBW 550ms DropTail
	$ns duplex-link $n(319) $n(322) $linkBW 60ms DropTail
	$ns duplex-link $n(319) $n(323) $linkBW 300ms DropTail
	$ns duplex-link $n(320) $n(322) $linkBW 140ms DropTail
	$ns duplex-link $n(321) $n(322) $linkBW 560ms DropTail
	$ns duplex-link $n(321) $n(323) $linkBW 280ms DropTail
	if {$verbose} { puts -nonewline "690..."; flush stdout }
	$ns duplex-link $n(322) $n(324) $linkBW 510ms DropTail
	$ns duplex-link $n(323) $n(324) $linkBW 230ms DropTail
	$ns duplex-link $n(325) $n(326) $linkBW 260ms DropTail
	$ns duplex-link $n(325) $n(328) $linkBW 270ms DropTail
	$ns duplex-link $n(325) $n(329) $linkBW 440ms DropTail
	$ns duplex-link $n(325) $n(331) $linkBW 40ms DropTail
	$ns duplex-link $n(325) $n(332) $linkBW 490ms DropTail
	$ns duplex-link $n(326) $n(327) $linkBW 150ms DropTail
	$ns duplex-link $n(326) $n(330) $linkBW 160ms DropTail
	$ns duplex-link $n(326) $n(331) $linkBW 230ms DropTail
	if {$verbose} { puts -nonewline "700..."; flush stdout }
	$ns duplex-link $n(326) $n(332) $linkBW 290ms DropTail
	$ns duplex-link $n(327) $n(329) $linkBW 170ms DropTail
	$ns duplex-link $n(327) $n(331) $linkBW 250ms DropTail
	$ns duplex-link $n(327) $n(332) $linkBW 210ms DropTail
	$ns duplex-link $n(328) $n(330) $linkBW 310ms DropTail
	$ns duplex-link $n(328) $n(331) $linkBW 240ms DropTail
	$ns duplex-link $n(329) $n(330) $linkBW 370ms DropTail
	$ns duplex-link $n(329) $n(331) $linkBW 410ms DropTail
	$ns duplex-link $n(329) $n(332) $linkBW 80ms DropTail
	$ns duplex-link $n(330) $n(331) $linkBW 150ms DropTail
	if {$verbose} { puts -nonewline "710..."; flush stdout }
	$ns duplex-link $n(330) $n(332) $linkBW 440ms DropTail
	$ns duplex-link $n(333) $n(334) $linkBW 320ms DropTail
	$ns duplex-link $n(333) $n(338) $linkBW 320ms DropTail
	$ns duplex-link $n(333) $n(341) $linkBW 220ms DropTail
	$ns duplex-link $n(334) $n(336) $linkBW 120ms DropTail
	$ns duplex-link $n(334) $n(337) $linkBW 520ms DropTail
	$ns duplex-link $n(334) $n(338) $linkBW 410ms DropTail
	$ns duplex-link $n(334) $n(339) $linkBW 470ms DropTail
	$ns duplex-link $n(334) $n(341) $linkBW 270ms DropTail
	$ns duplex-link $n(335) $n(341) $linkBW 50ms DropTail
	if {$verbose} { puts -nonewline "720..."; flush stdout }
	$ns duplex-link $n(336) $n(339) $linkBW 400ms DropTail
	$ns duplex-link $n(337) $n(338) $linkBW 120ms DropTail
	$ns duplex-link $n(337) $n(340) $linkBW 310ms DropTail
	$ns duplex-link $n(338) $n(340) $linkBW 250ms DropTail
	$ns duplex-link $n(338) $n(341) $linkBW 150ms DropTail
	$ns duplex-link $n(339) $n(341) $linkBW 230ms DropTail
	$ns duplex-link $n(342) $n(345) $linkBW 130ms DropTail
	$ns duplex-link $n(342) $n(346) $linkBW 630ms DropTail
	$ns duplex-link $n(342) $n(347) $linkBW 220ms DropTail
	$ns duplex-link $n(342) $n(348) $linkBW 380ms DropTail
	if {$verbose} { puts -nonewline "730..."; flush stdout }
	$ns duplex-link $n(343) $n(347) $linkBW 120ms DropTail
	$ns duplex-link $n(343) $n(348) $linkBW 310ms DropTail
	$ns duplex-link $n(344) $n(345) $linkBW 310ms DropTail
	$ns duplex-link $n(344) $n(346) $linkBW 390ms DropTail
	$ns duplex-link $n(344) $n(347) $linkBW 220ms DropTail
	$ns duplex-link $n(344) $n(348) $linkBW 140ms DropTail
	$ns duplex-link $n(345) $n(347) $linkBW 160ms DropTail
	$ns duplex-link $n(349) $n(350) $linkBW 540ms DropTail
	$ns duplex-link $n(349) $n(351) $linkBW 450ms DropTail
	$ns duplex-link $n(349) $n(352) $linkBW 390ms DropTail
	if {$verbose} { puts -nonewline "740..."; flush stdout }
	$ns duplex-link $n(349) $n(353) $linkBW 480ms DropTail
	$ns duplex-link $n(349) $n(355) $linkBW 560ms DropTail
	$ns duplex-link $n(350) $n(353) $linkBW 440ms DropTail
	$ns duplex-link $n(351) $n(352) $linkBW 210ms DropTail
	$ns duplex-link $n(351) $n(355) $linkBW 120ms DropTail
	$ns duplex-link $n(352) $n(355) $linkBW 250ms DropTail
	$ns duplex-link $n(353) $n(354) $linkBW 320ms DropTail
	$ns duplex-link $n(354) $n(355) $linkBW 410ms DropTail
	$ns duplex-link $n(356) $n(357) $linkBW 220ms DropTail
	$ns duplex-link $n(356) $n(358) $linkBW 340ms DropTail
	if {$verbose} { puts -nonewline "750..."; flush stdout }
	$ns duplex-link $n(356) $n(359) $linkBW 320ms DropTail
	$ns duplex-link $n(356) $n(360) $linkBW 440ms DropTail
	$ns duplex-link $n(356) $n(361) $linkBW 430ms DropTail
	$ns duplex-link $n(357) $n(358) $linkBW 330ms DropTail
	$ns duplex-link $n(357) $n(361) $linkBW 270ms DropTail
	$ns duplex-link $n(357) $n(362) $linkBW 170ms DropTail
	$ns duplex-link $n(358) $n(363) $linkBW 130ms DropTail
	$ns duplex-link $n(358) $n(364) $linkBW 190ms DropTail
	$ns duplex-link $n(359) $n(362) $linkBW 110ms DropTail
	$ns duplex-link $n(359) $n(363) $linkBW 430ms DropTail
	if {$verbose} { puts -nonewline "760..."; flush stdout }
	$ns duplex-link $n(360) $n(361) $linkBW 180ms DropTail
	$ns duplex-link $n(360) $n(362) $linkBW 320ms DropTail
	$ns duplex-link $n(360) $n(363) $linkBW 360ms DropTail
	$ns duplex-link $n(360) $n(364) $linkBW 450ms DropTail
	$ns duplex-link $n(361) $n(362) $linkBW 240ms DropTail
	$ns duplex-link $n(361) $n(363) $linkBW 460ms DropTail
	$ns duplex-link $n(362) $n(364) $linkBW 310ms DropTail
	$ns duplex-link $n(363) $n(364) $linkBW 140ms DropTail
	$ns duplex-link $n(365) $n(367) $linkBW 130ms DropTail
	$ns duplex-link $n(365) $n(370) $linkBW 210ms DropTail
	if {$verbose} { puts -nonewline "770..."; flush stdout }
	$ns duplex-link $n(365) $n(372) $linkBW 370ms DropTail
	$ns duplex-link $n(366) $n(367) $linkBW 120ms DropTail
	$ns duplex-link $n(366) $n(369) $linkBW 160ms DropTail
	$ns duplex-link $n(366) $n(370) $linkBW 80ms DropTail
	$ns duplex-link $n(366) $n(373) $linkBW 390ms DropTail
	$ns duplex-link $n(367) $n(368) $linkBW 210ms DropTail
	$ns duplex-link $n(367) $n(370) $linkBW 190ms DropTail
	$ns duplex-link $n(367) $n(371) $linkBW 300ms DropTail
	$ns duplex-link $n(367) $n(373) $linkBW 270ms DropTail
	$ns duplex-link $n(368) $n(369) $linkBW 110ms DropTail
	if {$verbose} { puts -nonewline "780..."; flush stdout }
	$ns duplex-link $n(368) $n(372) $linkBW 410ms DropTail
	$ns duplex-link $n(368) $n(373) $linkBW 370ms DropTail
	$ns duplex-link $n(369) $n(371) $linkBW 250ms DropTail
	$ns duplex-link $n(369) $n(372) $linkBW 380ms DropTail
	$ns duplex-link $n(369) $n(373) $linkBW 470ms DropTail
	$ns duplex-link $n(370) $n(371) $linkBW 320ms DropTail
	$ns duplex-link $n(371) $n(373) $linkBW 350ms DropTail
	$ns duplex-link $n(374) $n(378) $linkBW 370ms DropTail
	$ns duplex-link $n(374) $n(380) $linkBW 110ms DropTail
	$ns duplex-link $n(375) $n(380) $linkBW 260ms DropTail
	if {$verbose} { puts -nonewline "790..."; flush stdout }
	$ns duplex-link $n(376) $n(377) $linkBW 190ms DropTail
	$ns duplex-link $n(376) $n(379) $linkBW 170ms DropTail
	$ns duplex-link $n(377) $n(379) $linkBW 230ms DropTail
	$ns duplex-link $n(377) $n(380) $linkBW 390ms DropTail
	$ns duplex-link $n(381) $n(383) $linkBW 400ms DropTail
	$ns duplex-link $n(381) $n(384) $linkBW 300ms DropTail
	$ns duplex-link $n(381) $n(386) $linkBW 290ms DropTail
	$ns duplex-link $n(381) $n(387) $linkBW 240ms DropTail
	$ns duplex-link $n(382) $n(383) $linkBW 150ms DropTail
	$ns duplex-link $n(382) $n(384) $linkBW 90ms DropTail
	if {$verbose} { puts -nonewline "800..."; flush stdout }
	$ns duplex-link $n(383) $n(385) $linkBW 220ms DropTail
	$ns duplex-link $n(383) $n(386) $linkBW 230ms DropTail
	$ns duplex-link $n(383) $n(388) $linkBW 210ms DropTail
	$ns duplex-link $n(384) $n(387) $linkBW 310ms DropTail
	$ns duplex-link $n(385) $n(386) $linkBW 320ms DropTail
	$ns duplex-link $n(385) $n(387) $linkBW 380ms DropTail
	$ns duplex-link $n(385) $n(388) $linkBW 150ms DropTail
	$ns duplex-link $n(386) $n(387) $linkBW 110ms DropTail
	$ns duplex-link $n(386) $n(388) $linkBW 410ms DropTail
	$ns duplex-link $n(389) $n(390) $linkBW 340ms DropTail
	if {$verbose} { puts -nonewline "810..."; flush stdout }
	$ns duplex-link $n(389) $n(393) $linkBW 350ms DropTail
	$ns duplex-link $n(389) $n(394) $linkBW 340ms DropTail
	$ns duplex-link $n(389) $n(396) $linkBW 320ms DropTail
	$ns duplex-link $n(390) $n(391) $linkBW 520ms DropTail
	$ns duplex-link $n(390) $n(392) $linkBW 440ms DropTail
	$ns duplex-link $n(390) $n(393) $linkBW 310ms DropTail
	$ns duplex-link $n(390) $n(395) $linkBW 430ms DropTail
	$ns duplex-link $n(390) $n(396) $linkBW 150ms DropTail
	$ns duplex-link $n(391) $n(394) $linkBW 550ms DropTail
	$ns duplex-link $n(391) $n(395) $linkBW 190ms DropTail
	if {$verbose} { puts -nonewline "820..."; flush stdout }
	$ns duplex-link $n(391) $n(396) $linkBW 530ms DropTail
	$ns duplex-link $n(392) $n(393) $linkBW 360ms DropTail
	$ns duplex-link $n(392) $n(396) $linkBW 380ms DropTail
	$ns duplex-link $n(393) $n(394) $linkBW 150ms DropTail
	$ns duplex-link $n(393) $n(395) $linkBW 580ms DropTail
	$ns duplex-link $n(395) $n(396) $linkBW 490ms DropTail
	$ns duplex-link $n(397) $n(399) $linkBW 300ms DropTail
	$ns duplex-link $n(397) $n(400) $linkBW 480ms DropTail
	$ns duplex-link $n(397) $n(402) $linkBW 310ms DropTail
	$ns duplex-link $n(397) $n(405) $linkBW 400ms DropTail
	if {$verbose} { puts -nonewline "830..."; flush stdout }
	$ns duplex-link $n(397) $n(406) $linkBW 520ms DropTail
	$ns duplex-link $n(397) $n(407) $linkBW 210ms DropTail
	$ns duplex-link $n(398) $n(401) $linkBW 390ms DropTail
	$ns duplex-link $n(398) $n(402) $linkBW 300ms DropTail
	$ns duplex-link $n(398) $n(403) $linkBW 320ms DropTail
	$ns duplex-link $n(399) $n(400) $linkBW 310ms DropTail
	$ns duplex-link $n(399) $n(403) $linkBW 140ms DropTail
	$ns duplex-link $n(399) $n(404) $linkBW 460ms DropTail
	$ns duplex-link $n(399) $n(407) $linkBW 240ms DropTail
	$ns duplex-link $n(400) $n(402) $linkBW 190ms DropTail
	if {$verbose} { puts -nonewline "840..."; flush stdout }
	$ns duplex-link $n(400) $n(404) $linkBW 180ms DropTail
	$ns duplex-link $n(400) $n(407) $linkBW 280ms DropTail
	$ns duplex-link $n(401) $n(403) $linkBW 320ms DropTail
	$ns duplex-link $n(401) $n(404) $linkBW 150ms DropTail
	$ns duplex-link $n(401) $n(407) $linkBW 370ms DropTail
	$ns duplex-link $n(402) $n(403) $linkBW 30ms DropTail
	$ns duplex-link $n(402) $n(404) $linkBW 320ms DropTail
	$ns duplex-link $n(402) $n(405) $linkBW 90ms DropTail
	$ns duplex-link $n(403) $n(404) $linkBW 330ms DropTail
	$ns duplex-link $n(404) $n(406) $linkBW 150ms DropTail
	if {$verbose} { puts -nonewline "850..."; flush stdout }
	$ns duplex-link $n(404) $n(407) $linkBW 330ms DropTail
	$ns duplex-link $n(405) $n(406) $linkBW 190ms DropTail
	$ns duplex-link $n(408) $n(410) $linkBW 590ms DropTail
	$ns duplex-link $n(408) $n(413) $linkBW 320ms DropTail
	$ns duplex-link $n(408) $n(415) $linkBW 510ms DropTail
	$ns duplex-link $n(409) $n(410) $linkBW 210ms DropTail
	$ns duplex-link $n(409) $n(411) $linkBW 270ms DropTail
	$ns duplex-link $n(409) $n(413) $linkBW 330ms DropTail
	$ns duplex-link $n(409) $n(414) $linkBW 70ms DropTail
	$ns duplex-link $n(409) $n(415) $linkBW 250ms DropTail
	if {$verbose} { puts -nonewline "860..."; flush stdout }
	$ns duplex-link $n(410) $n(412) $linkBW 520ms DropTail
	$ns duplex-link $n(410) $n(415) $linkBW 450ms DropTail
	$ns duplex-link $n(411) $n(413) $linkBW 480ms DropTail
	$ns duplex-link $n(411) $n(415) $linkBW 490ms DropTail
	$ns duplex-link $n(412) $n(415) $linkBW 200ms DropTail
	$ns duplex-link $n(413) $n(415) $linkBW 210ms DropTail
	$ns duplex-link $n(416) $n(417) $linkBW 280ms DropTail
	$ns duplex-link $n(416) $n(420) $linkBW 340ms DropTail
	$ns duplex-link $n(417) $n(419) $linkBW 350ms DropTail
	$ns duplex-link $n(418) $n(419) $linkBW 230ms DropTail
	if {$verbose} { puts -nonewline "870..."; flush stdout }
	$ns duplex-link $n(419) $n(420) $linkBW 350ms DropTail
	$ns duplex-link $n(421) $n(422) $linkBW 280ms DropTail
	$ns duplex-link $n(421) $n(424) $linkBW 130ms DropTail
	$ns duplex-link $n(421) $n(425) $linkBW 140ms DropTail
	$ns duplex-link $n(421) $n(426) $linkBW 340ms DropTail
	$ns duplex-link $n(421) $n(427) $linkBW 230ms DropTail
	$ns duplex-link $n(422) $n(426) $linkBW 220ms DropTail
	$ns duplex-link $n(422) $n(427) $linkBW 170ms DropTail
	$ns duplex-link $n(422) $n(428) $linkBW 430ms DropTail
	$ns duplex-link $n(423) $n(426) $linkBW 270ms DropTail
	if {$verbose} { puts -nonewline "880..."; flush stdout }
	$ns duplex-link $n(423) $n(428) $linkBW 10ms DropTail
	$ns duplex-link $n(423) $n(429) $linkBW 440ms DropTail
	$ns duplex-link $n(424) $n(426) $linkBW 470ms DropTail
	$ns duplex-link $n(425) $n(427) $linkBW 150ms DropTail
	$ns duplex-link $n(425) $n(428) $linkBW 360ms DropTail
	$ns duplex-link $n(426) $n(428) $linkBW 260ms DropTail
	$ns duplex-link $n(427) $n(429) $linkBW 440ms DropTail
	$ns duplex-link $n(430) $n(435) $linkBW 410ms DropTail
	$ns duplex-link $n(431) $n(433) $linkBW 260ms DropTail
	$ns duplex-link $n(431) $n(434) $linkBW 360ms DropTail
	if {$verbose} { puts -nonewline "890..."; flush stdout }
	$ns duplex-link $n(431) $n(435) $linkBW 580ms DropTail
	$ns duplex-link $n(432) $n(433) $linkBW 400ms DropTail
	$ns duplex-link $n(434) $n(435) $linkBW 440ms DropTail
	$ns duplex-link $n(436) $n(440) $linkBW 400ms DropTail
	$ns duplex-link $n(436) $n(441) $linkBW 330ms DropTail
	$ns duplex-link $n(436) $n(442) $linkBW 400ms DropTail
	$ns duplex-link $n(436) $n(443) $linkBW 500ms DropTail
	$ns duplex-link $n(437) $n(438) $linkBW 380ms DropTail
	$ns duplex-link $n(437) $n(442) $linkBW 310ms DropTail
	$ns duplex-link $n(437) $n(443) $linkBW 370ms DropTail
	if {$verbose} { puts -nonewline "900..."; flush stdout }
	$ns duplex-link $n(437) $n(444) $linkBW 280ms DropTail
	$ns duplex-link $n(438) $n(439) $linkBW 200ms DropTail
	$ns duplex-link $n(439) $n(441) $linkBW 480ms DropTail
	$ns duplex-link $n(439) $n(442) $linkBW 170ms DropTail
	$ns duplex-link $n(439) $n(443) $linkBW 60ms DropTail
	$ns duplex-link $n(439) $n(444) $linkBW 40ms DropTail
	$ns duplex-link $n(440) $n(441) $linkBW 220ms DropTail
	$ns duplex-link $n(440) $n(442) $linkBW 130ms DropTail
	$ns duplex-link $n(441) $n(442) $linkBW 330ms DropTail
	$ns duplex-link $n(441) $n(443) $linkBW 510ms DropTail
	if {$verbose} { puts -nonewline "910..."; flush stdout }
	$ns duplex-link $n(442) $n(444) $linkBW 180ms DropTail
	$ns duplex-link $n(443) $n(444) $linkBW 100ms DropTail
	$ns duplex-link $n(445) $n(447) $linkBW 190ms DropTail
	$ns duplex-link $n(446) $n(447) $linkBW 40ms DropTail
	$ns duplex-link $n(447) $n(449) $linkBW 200ms DropTail
	$ns duplex-link $n(447) $n(450) $linkBW 550ms DropTail
	$ns duplex-link $n(448) $n(449) $linkBW 380ms DropTail
	$ns duplex-link $n(451) $n(453) $linkBW 130ms DropTail
	$ns duplex-link $n(451) $n(455) $linkBW 220ms DropTail
	$ns duplex-link $n(451) $n(457) $linkBW 140ms DropTail
	if {$verbose} { puts -nonewline "920..."; flush stdout }
	$ns duplex-link $n(452) $n(455) $linkBW 160ms DropTail
	$ns duplex-link $n(452) $n(457) $linkBW 250ms DropTail
	$ns duplex-link $n(452) $n(458) $linkBW 230ms DropTail
	$ns duplex-link $n(453) $n(454) $linkBW 450ms DropTail
	$ns duplex-link $n(453) $n(456) $linkBW 360ms DropTail
	$ns duplex-link $n(453) $n(457) $linkBW 140ms DropTail
	$ns duplex-link $n(454) $n(456) $linkBW 180ms DropTail
	$ns duplex-link $n(454) $n(458) $linkBW 260ms DropTail
	$ns duplex-link $n(454) $n(459) $linkBW 240ms DropTail
	$ns duplex-link $n(455) $n(456) $linkBW 30ms DropTail
	if {$verbose} { puts -nonewline "930..."; flush stdout }
	$ns duplex-link $n(455) $n(457) $linkBW 340ms DropTail
	$ns duplex-link $n(456) $n(459) $linkBW 120ms DropTail
	$ns duplex-link $n(457) $n(459) $linkBW 240ms DropTail
	$ns duplex-link $n(458) $n(459) $linkBW 90ms DropTail
	$ns duplex-link $n(460) $n(464) $linkBW 310ms DropTail
	$ns duplex-link $n(460) $n(465) $linkBW 280ms DropTail
	$ns duplex-link $n(460) $n(466) $linkBW 170ms DropTail
	$ns duplex-link $n(460) $n(467) $linkBW 440ms DropTail
	$ns duplex-link $n(461) $n(462) $linkBW 230ms DropTail
	$ns duplex-link $n(461) $n(463) $linkBW 130ms DropTail
	if {$verbose} { puts -nonewline "940..."; flush stdout }
	$ns duplex-link $n(461) $n(464) $linkBW 430ms DropTail
	$ns duplex-link $n(461) $n(465) $linkBW 250ms DropTail
	$ns duplex-link $n(461) $n(466) $linkBW 600ms DropTail
	$ns duplex-link $n(461) $n(467) $linkBW 260ms DropTail
	$ns duplex-link $n(462) $n(463) $linkBW 120ms DropTail
	$ns duplex-link $n(463) $n(465) $linkBW 120ms DropTail
	$ns duplex-link $n(463) $n(466) $linkBW 480ms DropTail
	$ns duplex-link $n(463) $n(467) $linkBW 310ms DropTail
	$ns duplex-link $n(464) $n(465) $linkBW 180ms DropTail
	$ns duplex-link $n(464) $n(467) $linkBW 560ms DropTail
	if {$verbose} { puts -nonewline "950..."; flush stdout }
	$ns duplex-link $n(467) $n(468) $linkBW 430ms DropTail
	$ns duplex-link $n(469) $n(470) $linkBW 530ms DropTail
	$ns duplex-link $n(469) $n(471) $linkBW 480ms DropTail
	$ns duplex-link $n(469) $n(472) $linkBW 160ms DropTail
	$ns duplex-link $n(469) $n(473) $linkBW 120ms DropTail
	$ns duplex-link $n(469) $n(474) $linkBW 420ms DropTail
	$ns duplex-link $n(469) $n(475) $linkBW 440ms DropTail
	$ns duplex-link $n(470) $n(472) $linkBW 640ms DropTail
	$ns duplex-link $n(470) $n(474) $linkBW 310ms DropTail
	$ns duplex-link $n(471) $n(472) $linkBW 440ms DropTail
	if {$verbose} { puts -nonewline "960..."; flush stdout }
	$ns duplex-link $n(471) $n(474) $linkBW 210ms DropTail
	$ns duplex-link $n(472) $n(473) $linkBW 140ms DropTail
	$ns duplex-link $n(472) $n(475) $linkBW 460ms DropTail
	$ns duplex-link $n(476) $n(478) $linkBW 260ms DropTail
	$ns duplex-link $n(476) $n(480) $linkBW 320ms DropTail
	$ns duplex-link $n(476) $n(482) $linkBW 400ms DropTail
	$ns duplex-link $n(477) $n(480) $linkBW 310ms DropTail
	$ns duplex-link $n(477) $n(482) $linkBW 260ms DropTail
	$ns duplex-link $n(478) $n(480) $linkBW 540ms DropTail
	$ns duplex-link $n(478) $n(481) $linkBW 330ms DropTail
	if {$verbose} { puts -nonewline "970..."; flush stdout }
	$ns duplex-link $n(479) $n(481) $linkBW 310ms DropTail
	$ns duplex-link $n(479) $n(482) $linkBW 210ms DropTail
	$ns duplex-link $n(483) $n(484) $linkBW 230ms DropTail
	$ns duplex-link $n(483) $n(486) $linkBW 450ms DropTail
	$ns duplex-link $n(483) $n(487) $linkBW 120ms DropTail
	$ns duplex-link $n(483) $n(488) $linkBW 250ms DropTail
	$ns duplex-link $n(483) $n(490) $linkBW 290ms DropTail
	$ns duplex-link $n(483) $n(491) $linkBW 420ms DropTail
	$ns duplex-link $n(484) $n(485) $linkBW 10ms DropTail
	$ns duplex-link $n(484) $n(488) $linkBW 40ms DropTail
	if {$verbose} { puts -nonewline "980..."; flush stdout }
	$ns duplex-link $n(484) $n(491) $linkBW 340ms DropTail
	$ns duplex-link $n(484) $n(492) $linkBW 90ms DropTail
	$ns duplex-link $n(485) $n(489) $linkBW 500ms DropTail
	$ns duplex-link $n(485) $n(490) $linkBW 70ms DropTail
	$ns duplex-link $n(485) $n(491) $linkBW 350ms DropTail
	$ns duplex-link $n(485) $n(492) $linkBW 90ms DropTail
	$ns duplex-link $n(486) $n(491) $linkBW 220ms DropTail
	$ns duplex-link $n(487) $n(488) $linkBW 330ms DropTail
	$ns duplex-link $n(487) $n(491) $linkBW 380ms DropTail
	$ns duplex-link $n(487) $n(492) $linkBW 220ms DropTail
	if {$verbose} { puts -nonewline "990..."; flush stdout }
	$ns duplex-link $n(488) $n(489) $linkBW 530ms DropTail
	$ns duplex-link $n(488) $n(490) $linkBW 90ms DropTail
	$ns duplex-link $n(488) $n(491) $linkBW 370ms DropTail
	$ns duplex-link $n(488) $n(492) $linkBW 110ms DropTail
	$ns duplex-link $n(489) $n(490) $linkBW 510ms DropTail
	$ns duplex-link $n(489) $n(491) $linkBW 390ms DropTail
	$ns duplex-link $n(489) $n(492) $linkBW 430ms DropTail
	$ns duplex-link $n(490) $n(492) $linkBW 150ms DropTail
	$ns duplex-link $n(491) $n(492) $linkBW 350ms DropTail
	$ns duplex-link $n(493) $n(494) $linkBW 680ms DropTail
	if {$verbose} { puts -nonewline "1000..."; flush stdout }
	$ns duplex-link $n(493) $n(495) $linkBW 100ms DropTail
	$ns duplex-link $n(493) $n(496) $linkBW 450ms DropTail
	$ns duplex-link $n(493) $n(497) $linkBW 400ms DropTail
	$ns duplex-link $n(493) $n(498) $linkBW 290ms DropTail
	$ns duplex-link $n(494) $n(496) $linkBW 560ms DropTail
	$ns duplex-link $n(494) $n(497) $linkBW 290ms DropTail
	$ns duplex-link $n(495) $n(497) $linkBW 300ms DropTail
	$ns duplex-link $n(496) $n(497) $linkBW 430ms DropTail
	$ns duplex-link $n(496) $n(498) $linkBW 170ms DropTail
	$ns duplex-link $n(497) $n(498) $linkBW 310ms DropTail
	if {$verbose} { puts -nonewline "1010..."; flush stdout }
	$ns duplex-link $n(499) $n(500) $linkBW 210ms DropTail
	$ns duplex-link $n(499) $n(501) $linkBW 90ms DropTail
	$ns duplex-link $n(499) $n(503) $linkBW 120ms DropTail
	$ns duplex-link $n(499) $n(507) $linkBW 390ms DropTail
	$ns duplex-link $n(500) $n(501) $linkBW 190ms DropTail
	$ns duplex-link $n(500) $n(502) $linkBW 240ms DropTail
	$ns duplex-link $n(500) $n(504) $linkBW 320ms DropTail
	$ns duplex-link $n(500) $n(506) $linkBW 140ms DropTail
	$ns duplex-link $n(500) $n(507) $linkBW 410ms DropTail
	$ns duplex-link $n(501) $n(503) $linkBW 130ms DropTail
	if {$verbose} { puts -nonewline "1020..."; flush stdout }
	$ns duplex-link $n(501) $n(505) $linkBW 330ms DropTail
	$ns duplex-link $n(501) $n(507) $linkBW 460ms DropTail
	$ns duplex-link $n(501) $n(508) $linkBW 90ms DropTail
	$ns duplex-link $n(502) $n(503) $linkBW 530ms DropTail
	$ns duplex-link $n(502) $n(504) $linkBW 490ms DropTail
	$ns duplex-link $n(502) $n(507) $linkBW 370ms DropTail
	$ns duplex-link $n(502) $n(508) $linkBW 490ms DropTail
	$ns duplex-link $n(503) $n(504) $linkBW 150ms DropTail
	$ns duplex-link $n(504) $n(507) $linkBW 370ms DropTail
	$ns duplex-link $n(505) $n(507) $linkBW 480ms DropTail
	if {$verbose} { puts -nonewline "1030..."; flush stdout }
	$ns duplex-link $n(505) $n(508) $linkBW 380ms DropTail
	$ns duplex-link $n(506) $n(507) $linkBW 450ms DropTail
	$ns duplex-link $n(506) $n(508) $linkBW 390ms DropTail
	$ns duplex-link $n(509) $n(510) $linkBW 340ms DropTail
	$ns duplex-link $n(509) $n(511) $linkBW 120ms DropTail
	$ns duplex-link $n(509) $n(514) $linkBW 270ms DropTail
	$ns duplex-link $n(509) $n(516) $linkBW 450ms DropTail
	$ns duplex-link $n(510) $n(511) $linkBW 330ms DropTail
	$ns duplex-link $n(510) $n(512) $linkBW 140ms DropTail
	$ns duplex-link $n(510) $n(514) $linkBW 80ms DropTail
	if {$verbose} { puts -nonewline "1040..."; flush stdout }
	$ns duplex-link $n(511) $n(512) $linkBW 220ms DropTail
	$ns duplex-link $n(511) $n(514) $linkBW 250ms DropTail
	$ns duplex-link $n(511) $n(516) $linkBW 430ms DropTail
	$ns duplex-link $n(512) $n(514) $linkBW 70ms DropTail
	$ns duplex-link $n(512) $n(515) $linkBW 330ms DropTail
	$ns duplex-link $n(512) $n(516) $linkBW 240ms DropTail
	$ns duplex-link $n(513) $n(515) $linkBW 420ms DropTail
	$ns duplex-link $n(514) $n(515) $linkBW 370ms DropTail
	$ns duplex-link $n(517) $n(519) $linkBW 480ms DropTail
	$ns duplex-link $n(517) $n(522) $linkBW 90ms DropTail
	if {$verbose} { puts -nonewline "1050..."; flush stdout }
	$ns duplex-link $n(517) $n(523) $linkBW 420ms DropTail
	$ns duplex-link $n(518) $n(519) $linkBW 430ms DropTail
	$ns duplex-link $n(518) $n(521) $linkBW 400ms DropTail
	$ns duplex-link $n(518) $n(522) $linkBW 160ms DropTail
	$ns duplex-link $n(518) $n(523) $linkBW 500ms DropTail
	$ns duplex-link $n(519) $n(520) $linkBW 520ms DropTail
	$ns duplex-link $n(519) $n(521) $linkBW 260ms DropTail
	$ns duplex-link $n(519) $n(522) $linkBW 570ms DropTail
	$ns duplex-link $n(519) $n(524) $linkBW 520ms DropTail
	$ns duplex-link $n(520) $n(521) $linkBW 480ms DropTail
	if {$verbose} { puts -nonewline "1060..."; flush stdout }
	$ns duplex-link $n(520) $n(522) $linkBW 90ms DropTail
	$ns duplex-link $n(521) $n(524) $linkBW 260ms DropTail
	$ns duplex-link $n(522) $n(523) $linkBW 460ms DropTail
	$ns duplex-link $n(525) $n(569) $linkBW 300ms DropTail
	$ns duplex-link $n(525) $n(568) $linkBW 540ms DropTail
	$ns duplex-link $n(525) $n(556) $linkBW 400ms DropTail
	$ns duplex-link $n(525) $n(548) $linkBW 500ms DropTail
	$ns duplex-link $n(525) $n(544) $linkBW 180ms DropTail
	$ns duplex-link $n(525) $n(526) $linkBW 500ms DropTail
	$ns duplex-link $n(525) $n(527) $linkBW 590ms DropTail
	if {$verbose} { puts -nonewline "1070..."; flush stdout }
	$ns duplex-link $n(525) $n(532) $linkBW 290ms DropTail
	$ns duplex-link $n(525) $n(533) $linkBW 310ms DropTail
	$ns duplex-link $n(525) $n(534) $linkBW 410ms DropTail
	$ns duplex-link $n(525) $n(535) $linkBW 50ms DropTail
	$ns duplex-link $n(525) $n(536) $linkBW 490ms DropTail
	$ns duplex-link $n(526) $n(605) $linkBW 260ms DropTail
	$ns duplex-link $n(526) $n(599) $linkBW 230ms DropTail
	$ns duplex-link $n(526) $n(585) $linkBW 110ms DropTail
	$ns duplex-link $n(526) $n(577) $linkBW 510ms DropTail
	$ns duplex-link $n(526) $n(528) $linkBW 190ms DropTail
	if {$verbose} { puts -nonewline "1080..."; flush stdout }
	$ns duplex-link $n(526) $n(532) $linkBW 210ms DropTail
	$ns duplex-link $n(526) $n(535) $linkBW 450ms DropTail
	$ns duplex-link $n(526) $n(536) $linkBW 220ms DropTail
	$ns duplex-link $n(527) $n(830) $linkBW 830ms DropTail
	$ns duplex-link $n(527) $n(621) $linkBW 170ms DropTail
	$ns duplex-link $n(527) $n(612) $linkBW 400ms DropTail
	$ns duplex-link $n(527) $n(528) $linkBW 370ms DropTail
	$ns duplex-link $n(527) $n(529) $linkBW 350ms DropTail
	$ns duplex-link $n(527) $n(530) $linkBW 380ms DropTail
	$ns duplex-link $n(527) $n(532) $linkBW 500ms DropTail
	if {$verbose} { puts -nonewline "1090..."; flush stdout }
	$ns duplex-link $n(527) $n(534) $linkBW 280ms DropTail
	$ns duplex-link $n(527) $n(536) $linkBW 340ms DropTail
	$ns duplex-link $n(528) $n(640) $linkBW 310ms DropTail
	$ns duplex-link $n(528) $n(627) $linkBW 230ms DropTail
	$ns duplex-link $n(528) $n(530) $linkBW 170ms DropTail
	$ns duplex-link $n(528) $n(531) $linkBW 450ms DropTail
	$ns duplex-link $n(528) $n(533) $linkBW 500ms DropTail
	$ns duplex-link $n(528) $n(534) $linkBW 480ms DropTail
	$ns duplex-link $n(528) $n(535) $linkBW 440ms DropTail
	$ns duplex-link $n(529) $n(646) $linkBW 170ms DropTail
	if {$verbose} { puts -nonewline "1100..."; flush stdout }
	$ns duplex-link $n(529) $n(530) $linkBW 300ms DropTail
	$ns duplex-link $n(529) $n(531) $linkBW 220ms DropTail
	$ns duplex-link $n(529) $n(533) $linkBW 60ms DropTail
	$ns duplex-link $n(529) $n(534) $linkBW 130ms DropTail
	$ns duplex-link $n(529) $n(535) $linkBW 280ms DropTail
	$ns duplex-link $n(530) $n(662) $linkBW 370ms DropTail
	$ns duplex-link $n(530) $n(654) $linkBW 380ms DropTail
	$ns duplex-link $n(530) $n(531) $linkBW 390ms DropTail
	$ns duplex-link $n(530) $n(534) $linkBW 380ms DropTail
	$ns duplex-link $n(530) $n(536) $linkBW 180ms DropTail
	if {$verbose} { puts -nonewline "1110..."; flush stdout }
	$ns duplex-link $n(531) $n(700) $linkBW 320ms DropTail
	$ns duplex-link $n(531) $n(693) $linkBW 50ms DropTail
	$ns duplex-link $n(531) $n(687) $linkBW 370ms DropTail
	$ns duplex-link $n(531) $n(678) $linkBW 320ms DropTail
	$ns duplex-link $n(531) $n(667) $linkBW 130ms DropTail
	$ns duplex-link $n(531) $n(532) $linkBW 500ms DropTail
	$ns duplex-link $n(531) $n(533) $linkBW 220ms DropTail
	$ns duplex-link $n(531) $n(535) $linkBW 490ms DropTail
	$ns duplex-link $n(531) $n(536) $linkBW 430ms DropTail
	$ns duplex-link $n(532) $n(715) $linkBW 320ms DropTail
	if {$verbose} { puts -nonewline "1120..."; flush stdout }
	$ns duplex-link $n(532) $n(707) $linkBW 470ms DropTail
	$ns duplex-link $n(532) $n(533) $linkBW 440ms DropTail
	$ns duplex-link $n(532) $n(534) $linkBW 480ms DropTail
	$ns duplex-link $n(532) $n(535) $linkBW 240ms DropTail
	$ns duplex-link $n(532) $n(536) $linkBW 250ms DropTail
	$ns duplex-link $n(533) $n(724) $linkBW 270ms DropTail
	$ns duplex-link $n(533) $n(535) $linkBW 320ms DropTail
	$ns duplex-link $n(533) $n(536) $linkBW 490ms DropTail
	$ns duplex-link $n(534) $n(759) $linkBW 90ms DropTail
	$ns duplex-link $n(534) $n(751) $linkBW 260ms DropTail
	if {$verbose} { puts -nonewline "1130..."; flush stdout }
	$ns duplex-link $n(534) $n(740) $linkBW 170ms DropTail
	$ns duplex-link $n(534) $n(731) $linkBW 280ms DropTail
	$ns duplex-link $n(534) $n(535) $linkBW 410ms DropTail
	$ns duplex-link $n(535) $n(798) $linkBW 400ms DropTail
	$ns duplex-link $n(535) $n(791) $linkBW 230ms DropTail
	$ns duplex-link $n(535) $n(781) $linkBW 30ms DropTail
	$ns duplex-link $n(535) $n(776) $linkBW 360ms DropTail
	$ns duplex-link $n(535) $n(761) $linkBW 350ms DropTail
	$ns duplex-link $n(536) $n(828) $linkBW 1000ms DropTail
	$ns duplex-link $n(536) $n(818) $linkBW 330ms DropTail
	if {$verbose} { puts -nonewline "1140..."; flush stdout }
	$ns duplex-link $n(536) $n(816) $linkBW 340ms DropTail
	$ns duplex-link $n(536) $n(809) $linkBW 90ms DropTail
	$ns duplex-link $n(537) $n(540) $linkBW 600ms DropTail
	$ns duplex-link $n(537) $n(541) $linkBW 300ms DropTail
	$ns duplex-link $n(537) $n(543) $linkBW 230ms DropTail
	$ns duplex-link $n(538) $n(540) $linkBW 230ms DropTail
	$ns duplex-link $n(538) $n(541) $linkBW 370ms DropTail
	$ns duplex-link $n(538) $n(543) $linkBW 260ms DropTail
	$ns duplex-link $n(539) $n(540) $linkBW 470ms DropTail
	$ns duplex-link $n(539) $n(541) $linkBW 220ms DropTail
	if {$verbose} { puts -nonewline "1150..."; flush stdout }
	$ns duplex-link $n(539) $n(542) $linkBW 460ms DropTail
	$ns duplex-link $n(539) $n(543) $linkBW 160ms DropTail
	$ns duplex-link $n(541) $n(542) $linkBW 290ms DropTail
	$ns duplex-link $n(541) $n(543) $linkBW 350ms DropTail
	$ns duplex-link $n(542) $n(544) $linkBW 250ms DropTail
	$ns duplex-link $n(543) $n(544) $linkBW 570ms DropTail
	$ns duplex-link $n(545) $n(547) $linkBW 440ms DropTail
	$ns duplex-link $n(545) $n(548) $linkBW 90ms DropTail
	$ns duplex-link $n(545) $n(550) $linkBW 190ms DropTail
	$ns duplex-link $n(545) $n(552) $linkBW 140ms DropTail
	if {$verbose} { puts -nonewline "1160..."; flush stdout }
	$ns duplex-link $n(546) $n(547) $linkBW 280ms DropTail
	$ns duplex-link $n(546) $n(548) $linkBW 250ms DropTail
	$ns duplex-link $n(546) $n(549) $linkBW 330ms DropTail
	$ns duplex-link $n(546) $n(551) $linkBW 300ms DropTail
	$ns duplex-link $n(546) $n(552) $linkBW 290ms DropTail
	$ns duplex-link $n(546) $n(553) $linkBW 120ms DropTail
	$ns duplex-link $n(546) $n(554) $linkBW 370ms DropTail
	$ns duplex-link $n(547) $n(549) $linkBW 320ms DropTail
	$ns duplex-link $n(547) $n(550) $linkBW 440ms DropTail
	$ns duplex-link $n(547) $n(552) $linkBW 520ms DropTail
	if {$verbose} { puts -nonewline "1170..."; flush stdout }
	$ns duplex-link $n(547) $n(553) $linkBW 190ms DropTail
	$ns duplex-link $n(547) $n(554) $linkBW 370ms DropTail
	$ns duplex-link $n(548) $n(549) $linkBW 430ms DropTail
	$ns duplex-link $n(548) $n(550) $linkBW 230ms DropTail
	$ns duplex-link $n(548) $n(551) $linkBW 220ms DropTail
	$ns duplex-link $n(548) $n(552) $linkBW 110ms DropTail
	$ns duplex-link $n(549) $n(553) $linkBW 240ms DropTail
	$ns duplex-link $n(549) $n(554) $linkBW 50ms DropTail
	$ns duplex-link $n(551) $n(552) $linkBW 330ms DropTail
	$ns duplex-link $n(551) $n(553) $linkBW 420ms DropTail
	if {$verbose} { puts -nonewline "1180..."; flush stdout }
	$ns duplex-link $n(555) $n(556) $linkBW 480ms DropTail
	$ns duplex-link $n(555) $n(557) $linkBW 430ms DropTail
	$ns duplex-link $n(555) $n(558) $linkBW 530ms DropTail
	$ns duplex-link $n(556) $n(557) $linkBW 350ms DropTail
	$ns duplex-link $n(556) $n(560) $linkBW 180ms DropTail
	$ns duplex-link $n(556) $n(561) $linkBW 320ms DropTail
	$ns duplex-link $n(557) $n(559) $linkBW 290ms DropTail
	$ns duplex-link $n(557) $n(560) $linkBW 210ms DropTail
	$ns duplex-link $n(557) $n(561) $linkBW 460ms DropTail
	$ns duplex-link $n(558) $n(559) $linkBW 450ms DropTail
	if {$verbose} { puts -nonewline "1190..."; flush stdout }
	$ns duplex-link $n(559) $n(560) $linkBW 430ms DropTail
	$ns duplex-link $n(559) $n(562) $linkBW 70ms DropTail
	$ns duplex-link $n(560) $n(561) $linkBW 280ms DropTail
	$ns duplex-link $n(561) $n(562) $linkBW 530ms DropTail
	$ns duplex-link $n(563) $n(565) $linkBW 200ms DropTail
	$ns duplex-link $n(563) $n(566) $linkBW 230ms DropTail
	$ns duplex-link $n(563) $n(567) $linkBW 180ms DropTail
	$ns duplex-link $n(564) $n(567) $linkBW 400ms DropTail
	$ns duplex-link $n(564) $n(568) $linkBW 250ms DropTail
	$ns duplex-link $n(565) $n(566) $linkBW 340ms DropTail
	if {$verbose} { puts -nonewline "1200..."; flush stdout }
	$ns duplex-link $n(565) $n(567) $linkBW 60ms DropTail
	$ns duplex-link $n(565) $n(568) $linkBW 150ms DropTail
	$ns duplex-link $n(566) $n(567) $linkBW 280ms DropTail
	$ns duplex-link $n(567) $n(568) $linkBW 150ms DropTail
	$ns duplex-link $n(569) $n(570) $linkBW 180ms DropTail
	$ns duplex-link $n(569) $n(572) $linkBW 390ms DropTail
	$ns duplex-link $n(569) $n(573) $linkBW 280ms DropTail
	$ns duplex-link $n(569) $n(576) $linkBW 420ms DropTail
	$ns duplex-link $n(570) $n(571) $linkBW 210ms DropTail
	$ns duplex-link $n(570) $n(573) $linkBW 310ms DropTail
	if {$verbose} { puts -nonewline "1210..."; flush stdout }
	$ns duplex-link $n(570) $n(575) $linkBW 190ms DropTail
	$ns duplex-link $n(571) $n(574) $linkBW 310ms DropTail
	$ns duplex-link $n(571) $n(575) $linkBW 240ms DropTail
	$ns duplex-link $n(572) $n(573) $linkBW 190ms DropTail
	$ns duplex-link $n(573) $n(574) $linkBW 400ms DropTail
	$ns duplex-link $n(573) $n(576) $linkBW 390ms DropTail
	$ns duplex-link $n(577) $n(578) $linkBW 310ms DropTail
	$ns duplex-link $n(577) $n(579) $linkBW 540ms DropTail
	$ns duplex-link $n(577) $n(580) $linkBW 490ms DropTail
	$ns duplex-link $n(577) $n(581) $linkBW 340ms DropTail
	if {$verbose} { puts -nonewline "1220..."; flush stdout }
	$ns duplex-link $n(578) $n(579) $linkBW 330ms DropTail
	$ns duplex-link $n(578) $n(580) $linkBW 180ms DropTail
	$ns duplex-link $n(578) $n(581) $linkBW 40ms DropTail
	$ns duplex-link $n(578) $n(582) $linkBW 320ms DropTail
	$ns duplex-link $n(579) $n(581) $linkBW 330ms DropTail
	$ns duplex-link $n(579) $n(582) $linkBW 250ms DropTail
	$ns duplex-link $n(579) $n(583) $linkBW 440ms DropTail
	$ns duplex-link $n(580) $n(582) $linkBW 390ms DropTail
	$ns duplex-link $n(580) $n(583) $linkBW 320ms DropTail
	$ns duplex-link $n(580) $n(584) $linkBW 340ms DropTail
	if {$verbose} { puts -nonewline "1230..."; flush stdout }
	$ns duplex-link $n(581) $n(582) $linkBW 340ms DropTail
	$ns duplex-link $n(581) $n(583) $linkBW 170ms DropTail
	$ns duplex-link $n(582) $n(583) $linkBW 350ms DropTail
	$ns duplex-link $n(585) $n(588) $linkBW 180ms DropTail
	$ns duplex-link $n(585) $n(589) $linkBW 280ms DropTail
	$ns duplex-link $n(585) $n(593) $linkBW 230ms DropTail
	$ns duplex-link $n(586) $n(588) $linkBW 370ms DropTail
	$ns duplex-link $n(586) $n(589) $linkBW 150ms DropTail
	$ns duplex-link $n(586) $n(590) $linkBW 110ms DropTail
	$ns duplex-link $n(586) $n(592) $linkBW 120ms DropTail
	if {$verbose} { puts -nonewline "1240..."; flush stdout }
	$ns duplex-link $n(587) $n(590) $linkBW 160ms DropTail
	$ns duplex-link $n(587) $n(592) $linkBW 370ms DropTail
	$ns duplex-link $n(588) $n(590) $linkBW 300ms DropTail
	$ns duplex-link $n(588) $n(591) $linkBW 270ms DropTail
	$ns duplex-link $n(588) $n(592) $linkBW 470ms DropTail
	$ns duplex-link $n(590) $n(592) $linkBW 230ms DropTail
	$ns duplex-link $n(592) $n(593) $linkBW 500ms DropTail
	$ns duplex-link $n(594) $n(597) $linkBW 420ms DropTail
	$ns duplex-link $n(594) $n(599) $linkBW 390ms DropTail
	$ns duplex-link $n(594) $n(600) $linkBW 130ms DropTail
	if {$verbose} { puts -nonewline "1250..."; flush stdout }
	$ns duplex-link $n(595) $n(597) $linkBW 290ms DropTail
	$ns duplex-link $n(595) $n(599) $linkBW 210ms DropTail
	$ns duplex-link $n(595) $n(600) $linkBW 310ms DropTail
	$ns duplex-link $n(596) $n(597) $linkBW 380ms DropTail
	$ns duplex-link $n(596) $n(598) $linkBW 250ms DropTail
	$ns duplex-link $n(596) $n(599) $linkBW 370ms DropTail
	$ns duplex-link $n(596) $n(600) $linkBW 120ms DropTail
	$ns duplex-link $n(597) $n(599) $linkBW 140ms DropTail
	$ns duplex-link $n(597) $n(600) $linkBW 490ms DropTail
	$ns duplex-link $n(599) $n(600) $linkBW 490ms DropTail
	if {$verbose} { puts -nonewline "1260..."; flush stdout }
	$ns duplex-link $n(601) $n(605) $linkBW 370ms DropTail
	$ns duplex-link $n(601) $n(607) $linkBW 540ms DropTail
	$ns duplex-link $n(602) $n(604) $linkBW 340ms DropTail
	$ns duplex-link $n(603) $n(604) $linkBW 320ms DropTail
	$ns duplex-link $n(603) $n(607) $linkBW 450ms DropTail
	$ns duplex-link $n(603) $n(608) $linkBW 530ms DropTail
	$ns duplex-link $n(604) $n(605) $linkBW 330ms DropTail
	$ns duplex-link $n(604) $n(606) $linkBW 90ms DropTail
	$ns duplex-link $n(604) $n(608) $linkBW 510ms DropTail
	$ns duplex-link $n(605) $n(607) $linkBW 190ms DropTail
	if {$verbose} { puts -nonewline "1270..."; flush stdout }
	$ns duplex-link $n(606) $n(607) $linkBW 490ms DropTail
	$ns duplex-link $n(609) $n(612) $linkBW 190ms DropTail
	$ns duplex-link $n(609) $n(614) $linkBW 490ms DropTail
	$ns duplex-link $n(610) $n(613) $linkBW 460ms DropTail
	$ns duplex-link $n(611) $n(613) $linkBW 230ms DropTail
	$ns duplex-link $n(612) $n(613) $linkBW 220ms DropTail
	$ns duplex-link $n(615) $n(616) $linkBW 460ms DropTail
	$ns duplex-link $n(615) $n(620) $linkBW 530ms DropTail
	$ns duplex-link $n(616) $n(618) $linkBW 200ms DropTail
	$ns duplex-link $n(616) $n(621) $linkBW 420ms DropTail
	if {$verbose} { puts -nonewline "1280..."; flush stdout }
	$ns duplex-link $n(616) $n(622) $linkBW 340ms DropTail
	$ns duplex-link $n(616) $n(623) $linkBW 300ms DropTail
	$ns duplex-link $n(616) $n(624) $linkBW 250ms DropTail
	$ns duplex-link $n(617) $n(618) $linkBW 120ms DropTail
	$ns duplex-link $n(617) $n(619) $linkBW 620ms DropTail
	$ns duplex-link $n(617) $n(621) $linkBW 490ms DropTail
	$ns duplex-link $n(617) $n(622) $linkBW 380ms DropTail
	$ns duplex-link $n(617) $n(623) $linkBW 380ms DropTail
	$ns duplex-link $n(618) $n(620) $linkBW 130ms DropTail
	$ns duplex-link $n(618) $n(621) $linkBW 600ms DropTail
	if {$verbose} { puts -nonewline "1290..."; flush stdout }
	$ns duplex-link $n(619) $n(620) $linkBW 630ms DropTail
	$ns duplex-link $n(619) $n(621) $linkBW 130ms DropTail
	$ns duplex-link $n(619) $n(623) $linkBW 240ms DropTail
	$ns duplex-link $n(619) $n(624) $linkBW 290ms DropTail
	$ns duplex-link $n(620) $n(621) $linkBW 510ms DropTail
	$ns duplex-link $n(620) $n(623) $linkBW 390ms DropTail
	$ns duplex-link $n(621) $n(622) $linkBW 130ms DropTail
	$ns duplex-link $n(621) $n(623) $linkBW 120ms DropTail
	$ns duplex-link $n(621) $n(624) $linkBW 180ms DropTail
	$ns duplex-link $n(622) $n(624) $linkBW 150ms DropTail
	if {$verbose} { puts -nonewline "1300..."; flush stdout }
	$ns duplex-link $n(623) $n(624) $linkBW 60ms DropTail
	$ns duplex-link $n(625) $n(626) $linkBW 360ms DropTail
	$ns duplex-link $n(625) $n(627) $linkBW 390ms DropTail
	$ns duplex-link $n(625) $n(628) $linkBW 360ms DropTail
	$ns duplex-link $n(625) $n(629) $linkBW 250ms DropTail
	$ns duplex-link $n(625) $n(631) $linkBW 460ms DropTail
	$ns duplex-link $n(625) $n(633) $linkBW 320ms DropTail
	$ns duplex-link $n(625) $n(634) $linkBW 90ms DropTail
	$ns duplex-link $n(626) $n(629) $linkBW 430ms DropTail
	$ns duplex-link $n(626) $n(630) $linkBW 290ms DropTail
	if {$verbose} { puts -nonewline "1310..."; flush stdout }
	$ns duplex-link $n(626) $n(631) $linkBW 400ms DropTail
	$ns duplex-link $n(626) $n(632) $linkBW 520ms DropTail
	$ns duplex-link $n(626) $n(633) $linkBW 60ms DropTail
	$ns duplex-link $n(626) $n(634) $linkBW 330ms DropTail
	$ns duplex-link $n(626) $n(635) $linkBW 430ms DropTail
	$ns duplex-link $n(627) $n(628) $linkBW 330ms DropTail
	$ns duplex-link $n(627) $n(630) $linkBW 340ms DropTail
	$ns duplex-link $n(627) $n(631) $linkBW 320ms DropTail
	$ns duplex-link $n(627) $n(634) $linkBW 340ms DropTail
	$ns duplex-link $n(627) $n(635) $linkBW 370ms DropTail
	if {$verbose} { puts -nonewline "1320..."; flush stdout }
	$ns duplex-link $n(628) $n(629) $linkBW 160ms DropTail
	$ns duplex-link $n(628) $n(632) $linkBW 390ms DropTail
	$ns duplex-link $n(628) $n(633) $linkBW 420ms DropTail
	$ns duplex-link $n(628) $n(634) $linkBW 270ms DropTail
	$ns duplex-link $n(628) $n(635) $linkBW 40ms DropTail
	$ns duplex-link $n(629) $n(630) $linkBW 320ms DropTail
	$ns duplex-link $n(629) $n(631) $linkBW 270ms DropTail
	$ns duplex-link $n(629) $n(632) $linkBW 230ms DropTail
	$ns duplex-link $n(629) $n(633) $linkBW 430ms DropTail
	$ns duplex-link $n(629) $n(634) $linkBW 170ms DropTail
	if {$verbose} { puts -nonewline "1330..."; flush stdout }
	$ns duplex-link $n(629) $n(635) $linkBW 140ms DropTail
	$ns duplex-link $n(630) $n(631) $linkBW 480ms DropTail
	$ns duplex-link $n(630) $n(633) $linkBW 240ms DropTail
	$ns duplex-link $n(630) $n(635) $linkBW 410ms DropTail
	$ns duplex-link $n(631) $n(632) $linkBW 500ms DropTail
	$ns duplex-link $n(631) $n(633) $linkBW 440ms DropTail
	$ns duplex-link $n(632) $n(633) $linkBW 490ms DropTail
	$ns duplex-link $n(632) $n(635) $linkBW 370ms DropTail
	$ns duplex-link $n(633) $n(635) $linkBW 450ms DropTail
	$ns duplex-link $n(636) $n(637) $linkBW 330ms DropTail
	if {$verbose} { puts -nonewline "1340..."; flush stdout }
	$ns duplex-link $n(636) $n(638) $linkBW 420ms DropTail
	$ns duplex-link $n(636) $n(640) $linkBW 200ms DropTail
	$ns duplex-link $n(637) $n(640) $linkBW 260ms DropTail
	$ns duplex-link $n(638) $n(640) $linkBW 230ms DropTail
	$ns duplex-link $n(639) $n(640) $linkBW 220ms DropTail
	$ns duplex-link $n(641) $n(643) $linkBW 360ms DropTail
	$ns duplex-link $n(641) $n(644) $linkBW 130ms DropTail
	$ns duplex-link $n(641) $n(645) $linkBW 270ms DropTail
	$ns duplex-link $n(641) $n(646) $linkBW 180ms DropTail
	$ns duplex-link $n(642) $n(643) $linkBW 200ms DropTail
	if {$verbose} { puts -nonewline "1350..."; flush stdout }
	$ns duplex-link $n(642) $n(646) $linkBW 330ms DropTail
	$ns duplex-link $n(642) $n(648) $linkBW 20ms DropTail
	$ns duplex-link $n(643) $n(645) $linkBW 160ms DropTail
	$ns duplex-link $n(643) $n(646) $linkBW 330ms DropTail
	$ns duplex-link $n(643) $n(648) $linkBW 210ms DropTail
	$ns duplex-link $n(644) $n(645) $linkBW 380ms DropTail
	$ns duplex-link $n(644) $n(646) $linkBW 250ms DropTail
	$ns duplex-link $n(645) $n(647) $linkBW 330ms DropTail
	$ns duplex-link $n(645) $n(648) $linkBW 240ms DropTail
	$ns duplex-link $n(647) $n(648) $linkBW 410ms DropTail
	if {$verbose} { puts -nonewline "1360..."; flush stdout }
	$ns duplex-link $n(649) $n(654) $linkBW 420ms DropTail
	$ns duplex-link $n(650) $n(651) $linkBW 300ms DropTail
	$ns duplex-link $n(650) $n(652) $linkBW 500ms DropTail
	$ns duplex-link $n(650) $n(653) $linkBW 120ms DropTail
	$ns duplex-link $n(650) $n(654) $linkBW 380ms DropTail
	$ns duplex-link $n(651) $n(652) $linkBW 270ms DropTail
	$ns duplex-link $n(651) $n(654) $linkBW 300ms DropTail
	$ns duplex-link $n(652) $n(653) $linkBW 490ms DropTail
	$ns duplex-link $n(652) $n(654) $linkBW 210ms DropTail
	$ns duplex-link $n(653) $n(654) $linkBW 420ms DropTail
	if {$verbose} { puts -nonewline "1370..."; flush stdout }
	$ns duplex-link $n(655) $n(656) $linkBW 270ms DropTail
	$ns duplex-link $n(655) $n(657) $linkBW 300ms DropTail
	$ns duplex-link $n(655) $n(658) $linkBW 160ms DropTail
	$ns duplex-link $n(655) $n(661) $linkBW 360ms DropTail
	$ns duplex-link $n(655) $n(664) $linkBW 290ms DropTail
	$ns duplex-link $n(656) $n(659) $linkBW 460ms DropTail
	$ns duplex-link $n(656) $n(660) $linkBW 270ms DropTail
	$ns duplex-link $n(656) $n(662) $linkBW 90ms DropTail
	$ns duplex-link $n(656) $n(664) $linkBW 470ms DropTail
	$ns duplex-link $n(657) $n(658) $linkBW 380ms DropTail
	if {$verbose} { puts -nonewline "1380..."; flush stdout }
	$ns duplex-link $n(657) $n(660) $linkBW 420ms DropTail
	$ns duplex-link $n(657) $n(661) $linkBW 90ms DropTail
	$ns duplex-link $n(657) $n(663) $linkBW 390ms DropTail
	$ns duplex-link $n(657) $n(664) $linkBW 320ms DropTail
	$ns duplex-link $n(658) $n(659) $linkBW 600ms DropTail
	$ns duplex-link $n(658) $n(661) $linkBW 400ms DropTail
	$ns duplex-link $n(658) $n(662) $linkBW 150ms DropTail
	$ns duplex-link $n(659) $n(660) $linkBW 590ms DropTail
	$ns duplex-link $n(659) $n(661) $linkBW 250ms DropTail
	$ns duplex-link $n(659) $n(663) $linkBW 580ms DropTail
	if {$verbose} { puts -nonewline "1390..."; flush stdout }
	$ns duplex-link $n(659) $n(664) $linkBW 360ms DropTail
	$ns duplex-link $n(660) $n(661) $linkBW 350ms DropTail
	$ns duplex-link $n(660) $n(663) $linkBW 90ms DropTail
	$ns duplex-link $n(660) $n(664) $linkBW 720ms DropTail
	$ns duplex-link $n(661) $n(662) $linkBW 260ms DropTail
	$ns duplex-link $n(662) $n(663) $linkBW 280ms DropTail
	$ns duplex-link $n(663) $n(664) $linkBW 670ms DropTail
	$ns duplex-link $n(665) $n(666) $linkBW 160ms DropTail
	$ns duplex-link $n(665) $n(670) $linkBW 270ms DropTail
	$ns duplex-link $n(665) $n(674) $linkBW 220ms DropTail
	if {$verbose} { puts -nonewline "1400..."; flush stdout }
	$ns duplex-link $n(666) $n(668) $linkBW 350ms DropTail
	$ns duplex-link $n(666) $n(669) $linkBW 390ms DropTail
	$ns duplex-link $n(666) $n(673) $linkBW 280ms DropTail
	$ns duplex-link $n(666) $n(674) $linkBW 100ms DropTail
	$ns duplex-link $n(667) $n(671) $linkBW 530ms DropTail
	$ns duplex-link $n(668) $n(672) $linkBW 220ms DropTail
	$ns duplex-link $n(669) $n(670) $linkBW 500ms DropTail
	$ns duplex-link $n(669) $n(671) $linkBW 320ms DropTail
	$ns duplex-link $n(670) $n(672) $linkBW 270ms DropTail
	$ns duplex-link $n(671) $n(672) $linkBW 580ms DropTail
	if {$verbose} { puts -nonewline "1410..."; flush stdout }
	$ns duplex-link $n(671) $n(673) $linkBW 420ms DropTail
	$ns duplex-link $n(672) $n(674) $linkBW 570ms DropTail
	$ns duplex-link $n(675) $n(677) $linkBW 170ms DropTail
	$ns duplex-link $n(675) $n(679) $linkBW 490ms DropTail
	$ns duplex-link $n(675) $n(680) $linkBW 50ms DropTail
	$ns duplex-link $n(675) $n(682) $linkBW 170ms DropTail
	$ns duplex-link $n(675) $n(683) $linkBW 190ms DropTail
	$ns duplex-link $n(676) $n(678) $linkBW 660ms DropTail
	$ns duplex-link $n(676) $n(679) $linkBW 560ms DropTail
	$ns duplex-link $n(676) $n(680) $linkBW 430ms DropTail
	if {$verbose} { puts -nonewline "1420..."; flush stdout }
	$ns duplex-link $n(676) $n(681) $linkBW 500ms DropTail
	$ns duplex-link $n(676) $n(683) $linkBW 220ms DropTail
	$ns duplex-link $n(676) $n(684) $linkBW 210ms DropTail
	$ns duplex-link $n(677) $n(678) $linkBW 290ms DropTail
	$ns duplex-link $n(677) $n(682) $linkBW 170ms DropTail
	$ns duplex-link $n(678) $n(679) $linkBW 470ms DropTail
	$ns duplex-link $n(678) $n(682) $linkBW 430ms DropTail
	$ns duplex-link $n(679) $n(680) $linkBW 500ms DropTail
	$ns duplex-link $n(679) $n(683) $linkBW 410ms DropTail
	$ns duplex-link $n(679) $n(684) $linkBW 600ms DropTail
	if {$verbose} { puts -nonewline "1430..."; flush stdout }
	$ns duplex-link $n(681) $n(683) $linkBW 340ms DropTail
	$ns duplex-link $n(681) $n(684) $linkBW 520ms DropTail
	$ns duplex-link $n(682) $n(683) $linkBW 20ms DropTail
	$ns duplex-link $n(682) $n(684) $linkBW 170ms DropTail
	$ns duplex-link $n(685) $n(688) $linkBW 450ms DropTail
	$ns duplex-link $n(685) $n(689) $linkBW 330ms DropTail
	$ns duplex-link $n(685) $n(690) $linkBW 380ms DropTail
	$ns duplex-link $n(685) $n(691) $linkBW 70ms DropTail
	$ns duplex-link $n(685) $n(692) $linkBW 460ms DropTail
	$ns duplex-link $n(686) $n(687) $linkBW 320ms DropTail
	if {$verbose} { puts -nonewline "1440..."; flush stdout }
	$ns duplex-link $n(686) $n(688) $linkBW 140ms DropTail
	$ns duplex-link $n(686) $n(690) $linkBW 40ms DropTail
	$ns duplex-link $n(686) $n(692) $linkBW 40ms DropTail
	$ns duplex-link $n(687) $n(690) $linkBW 280ms DropTail
	$ns duplex-link $n(687) $n(692) $linkBW 350ms DropTail
	$ns duplex-link $n(688) $n(691) $linkBW 380ms DropTail
	$ns duplex-link $n(689) $n(690) $linkBW 510ms DropTail
	$ns duplex-link $n(689) $n(691) $linkBW 360ms DropTail
	$ns duplex-link $n(693) $n(694) $linkBW 340ms DropTail
	$ns duplex-link $n(695) $n(696) $linkBW 410ms DropTail
	if {$verbose} { puts -nonewline "1450..."; flush stdout }
	$ns duplex-link $n(695) $n(698) $linkBW 350ms DropTail
	$ns duplex-link $n(695) $n(699) $linkBW 180ms DropTail
	$ns duplex-link $n(696) $n(697) $linkBW 470ms DropTail
	$ns duplex-link $n(696) $n(699) $linkBW 250ms DropTail
	$ns duplex-link $n(696) $n(700) $linkBW 190ms DropTail
	$ns duplex-link $n(696) $n(702) $linkBW 300ms DropTail
	$ns duplex-link $n(696) $n(704) $linkBW 350ms DropTail
	$ns duplex-link $n(697) $n(698) $linkBW 430ms DropTail
	$ns duplex-link $n(697) $n(700) $linkBW 430ms DropTail
	$ns duplex-link $n(697) $n(702) $linkBW 200ms DropTail
	if {$verbose} { puts -nonewline "1460..."; flush stdout }
	$ns duplex-link $n(698) $n(699) $linkBW 170ms DropTail
	$ns duplex-link $n(698) $n(700) $linkBW 340ms DropTail
	$ns duplex-link $n(698) $n(702) $linkBW 330ms DropTail
	$ns duplex-link $n(699) $n(700) $linkBW 310ms DropTail
	$ns duplex-link $n(699) $n(702) $linkBW 190ms DropTail
	$ns duplex-link $n(699) $n(703) $linkBW 270ms DropTail
	$ns duplex-link $n(699) $n(704) $linkBW 180ms DropTail
	$ns duplex-link $n(700) $n(703) $linkBW 120ms DropTail
	$ns duplex-link $n(700) $n(704) $linkBW 480ms DropTail
	$ns duplex-link $n(701) $n(704) $linkBW 290ms DropTail
	if {$verbose} { puts -nonewline "1470..."; flush stdout }
	$ns duplex-link $n(702) $n(704) $linkBW 370ms DropTail
	$ns duplex-link $n(705) $n(708) $linkBW 60ms DropTail
	$ns duplex-link $n(705) $n(709) $linkBW 170ms DropTail
	$ns duplex-link $n(705) $n(711) $linkBW 500ms DropTail
	$ns duplex-link $n(705) $n(712) $linkBW 320ms DropTail
	$ns duplex-link $n(706) $n(707) $linkBW 300ms DropTail
	$ns duplex-link $n(706) $n(711) $linkBW 560ms DropTail
	$ns duplex-link $n(706) $n(713) $linkBW 450ms DropTail
	$ns duplex-link $n(707) $n(708) $linkBW 190ms DropTail
	$ns duplex-link $n(707) $n(709) $linkBW 270ms DropTail
	if {$verbose} { puts -nonewline "1480..."; flush stdout }
	$ns duplex-link $n(707) $n(710) $linkBW 190ms DropTail
	$ns duplex-link $n(707) $n(711) $linkBW 510ms DropTail
	$ns duplex-link $n(708) $n(709) $linkBW 190ms DropTail
	$ns duplex-link $n(708) $n(712) $linkBW 280ms DropTail
	$ns duplex-link $n(708) $n(713) $linkBW 380ms DropTail
	$ns duplex-link $n(709) $n(711) $linkBW 330ms DropTail
	$ns duplex-link $n(709) $n(713) $linkBW 220ms DropTail
	$ns duplex-link $n(710) $n(711) $linkBW 610ms DropTail
	$ns duplex-link $n(710) $n(712) $linkBW 300ms DropTail
	$ns duplex-link $n(710) $n(713) $linkBW 470ms DropTail
	if {$verbose} { puts -nonewline "1490..."; flush stdout }
	$ns duplex-link $n(712) $n(713) $linkBW 280ms DropTail
	$ns duplex-link $n(714) $n(717) $linkBW 360ms DropTail
	$ns duplex-link $n(715) $n(717) $linkBW 210ms DropTail
	$ns duplex-link $n(715) $n(718) $linkBW 370ms DropTail
	$ns duplex-link $n(716) $n(717) $linkBW 260ms DropTail
	$ns duplex-link $n(716) $n(718) $linkBW 450ms DropTail
	$ns duplex-link $n(716) $n(720) $linkBW 390ms DropTail
	$ns duplex-link $n(717) $n(718) $linkBW 200ms DropTail
	$ns duplex-link $n(717) $n(720) $linkBW 190ms DropTail
	$ns duplex-link $n(719) $n(720) $linkBW 430ms DropTail
	if {$verbose} { puts -nonewline "1500..."; flush stdout }
	$ns duplex-link $n(721) $n(722) $linkBW 310ms DropTail
	$ns duplex-link $n(721) $n(724) $linkBW 90ms DropTail
	$ns duplex-link $n(721) $n(725) $linkBW 330ms DropTail
	$ns duplex-link $n(721) $n(727) $linkBW 230ms DropTail
	$ns duplex-link $n(722) $n(723) $linkBW 230ms DropTail
	$ns duplex-link $n(722) $n(725) $linkBW 380ms DropTail
	$ns duplex-link $n(722) $n(726) $linkBW 50ms DropTail
	$ns duplex-link $n(722) $n(728) $linkBW 380ms DropTail
	$ns duplex-link $n(723) $n(724) $linkBW 210ms DropTail
	$ns duplex-link $n(724) $n(725) $linkBW 350ms DropTail
	if {$verbose} { puts -nonewline "1510..."; flush stdout }
	$ns duplex-link $n(724) $n(728) $linkBW 390ms DropTail
	$ns duplex-link $n(725) $n(727) $linkBW 550ms DropTail
	$ns duplex-link $n(725) $n(728) $linkBW 640ms DropTail
	$ns duplex-link $n(726) $n(727) $linkBW 370ms DropTail
	$ns duplex-link $n(729) $n(732) $linkBW 350ms DropTail
	$ns duplex-link $n(729) $n(733) $linkBW 70ms DropTail
	$ns duplex-link $n(729) $n(735) $linkBW 150ms DropTail
	$ns duplex-link $n(730) $n(733) $linkBW 350ms DropTail
	$ns duplex-link $n(730) $n(734) $linkBW 140ms DropTail
	$ns duplex-link $n(730) $n(735) $linkBW 130ms DropTail
	if {$verbose} { puts -nonewline "1520..."; flush stdout }
	$ns duplex-link $n(731) $n(732) $linkBW 190ms DropTail
	$ns duplex-link $n(731) $n(733) $linkBW 230ms DropTail
	$ns duplex-link $n(734) $n(735) $linkBW 180ms DropTail
	$ns duplex-link $n(736) $n(740) $linkBW 470ms DropTail
	$ns duplex-link $n(736) $n(741) $linkBW 330ms DropTail
	$ns duplex-link $n(737) $n(738) $linkBW 60ms DropTail
	$ns duplex-link $n(737) $n(740) $linkBW 220ms DropTail
	$ns duplex-link $n(737) $n(741) $linkBW 410ms DropTail
	$ns duplex-link $n(738) $n(741) $linkBW 350ms DropTail
	$ns duplex-link $n(739) $n(740) $linkBW 520ms DropTail
	if {$verbose} { puts -nonewline "1530..."; flush stdout }
	$ns duplex-link $n(739) $n(741) $linkBW 500ms DropTail
	$ns duplex-link $n(740) $n(741) $linkBW 310ms DropTail
	$ns duplex-link $n(742) $n(745) $linkBW 220ms DropTail
	$ns duplex-link $n(742) $n(746) $linkBW 180ms DropTail
	$ns duplex-link $n(742) $n(747) $linkBW 290ms DropTail
	$ns duplex-link $n(742) $n(751) $linkBW 110ms DropTail
	$ns duplex-link $n(743) $n(744) $linkBW 250ms DropTail
	$ns duplex-link $n(743) $n(746) $linkBW 190ms DropTail
	$ns duplex-link $n(743) $n(747) $linkBW 130ms DropTail
	$ns duplex-link $n(744) $n(745) $linkBW 200ms DropTail
	if {$verbose} { puts -nonewline "1540..."; flush stdout }
	$ns duplex-link $n(744) $n(749) $linkBW 500ms DropTail
	$ns duplex-link $n(745) $n(748) $linkBW 70ms DropTail
	$ns duplex-link $n(745) $n(749) $linkBW 370ms DropTail
	$ns duplex-link $n(745) $n(750) $linkBW 210ms DropTail
	$ns duplex-link $n(746) $n(748) $linkBW 300ms DropTail
	$ns duplex-link $n(746) $n(749) $linkBW 390ms DropTail
	$ns duplex-link $n(746) $n(750) $linkBW 450ms DropTail
	$ns duplex-link $n(746) $n(751) $linkBW 250ms DropTail
	$ns duplex-link $n(747) $n(749) $linkBW 490ms DropTail
	$ns duplex-link $n(748) $n(750) $linkBW 180ms DropTail
	if {$verbose} { puts -nonewline "1550..."; flush stdout }
	$ns duplex-link $n(749) $n(750) $linkBW 510ms DropTail
	$ns duplex-link $n(750) $n(751) $linkBW 310ms DropTail
	$ns duplex-link $n(752) $n(756) $linkBW 250ms DropTail
	$ns duplex-link $n(752) $n(758) $linkBW 280ms DropTail
	$ns duplex-link $n(752) $n(760) $linkBW 270ms DropTail
	$ns duplex-link $n(753) $n(755) $linkBW 260ms DropTail
	$ns duplex-link $n(753) $n(756) $linkBW 180ms DropTail
	$ns duplex-link $n(753) $n(760) $linkBW 460ms DropTail
	$ns duplex-link $n(754) $n(755) $linkBW 160ms DropTail
	$ns duplex-link $n(754) $n(756) $linkBW 180ms DropTail
	if {$verbose} { puts -nonewline "1560..."; flush stdout }
	$ns duplex-link $n(754) $n(757) $linkBW 310ms DropTail
	$ns duplex-link $n(754) $n(758) $linkBW 160ms DropTail
	$ns duplex-link $n(754) $n(759) $linkBW 410ms DropTail
	$ns duplex-link $n(755) $n(759) $linkBW 270ms DropTail
	$ns duplex-link $n(756) $n(757) $linkBW 160ms DropTail
	$ns duplex-link $n(756) $n(758) $linkBW 30ms DropTail
	$ns duplex-link $n(756) $n(759) $linkBW 330ms DropTail
	$ns duplex-link $n(758) $n(759) $linkBW 350ms DropTail
	$ns duplex-link $n(758) $n(760) $linkBW 360ms DropTail
	$ns duplex-link $n(761) $n(763) $linkBW 190ms DropTail
	if {$verbose} { puts -nonewline "1570..."; flush stdout }
	$ns duplex-link $n(761) $n(764) $linkBW 400ms DropTail
	$ns duplex-link $n(761) $n(765) $linkBW 440ms DropTail
	$ns duplex-link $n(761) $n(767) $linkBW 400ms DropTail
	$ns duplex-link $n(761) $n(769) $linkBW 450ms DropTail
	$ns duplex-link $n(761) $n(771) $linkBW 480ms DropTail
	$ns duplex-link $n(762) $n(763) $linkBW 280ms DropTail
	$ns duplex-link $n(762) $n(765) $linkBW 150ms DropTail
	$ns duplex-link $n(762) $n(767) $linkBW 590ms DropTail
	$ns duplex-link $n(762) $n(768) $linkBW 240ms DropTail
	$ns duplex-link $n(762) $n(769) $linkBW 270ms DropTail
	if {$verbose} { puts -nonewline "1580..."; flush stdout }
	$ns duplex-link $n(763) $n(765) $linkBW 290ms DropTail
	$ns duplex-link $n(763) $n(768) $linkBW 140ms DropTail
	$ns duplex-link $n(763) $n(769) $linkBW 270ms DropTail
	$ns duplex-link $n(764) $n(766) $linkBW 460ms DropTail
	$ns duplex-link $n(764) $n(768) $linkBW 390ms DropTail
	$ns duplex-link $n(764) $n(771) $linkBW 150ms DropTail
	$ns duplex-link $n(765) $n(766) $linkBW 250ms DropTail
	$ns duplex-link $n(765) $n(769) $linkBW 140ms DropTail
	$ns duplex-link $n(766) $n(770) $linkBW 230ms DropTail
	$ns duplex-link $n(767) $n(768) $linkBW 430ms DropTail
	if {$verbose} { puts -nonewline "1590..."; flush stdout }
	$ns duplex-link $n(767) $n(769) $linkBW 450ms DropTail
	$ns duplex-link $n(767) $n(770) $linkBW 590ms DropTail
	$ns duplex-link $n(767) $n(771) $linkBW 260ms DropTail
	$ns duplex-link $n(768) $n(769) $linkBW 360ms DropTail
	$ns duplex-link $n(768) $n(770) $linkBW 320ms DropTail
	$ns duplex-link $n(769) $n(770) $linkBW 200ms DropTail
	$ns duplex-link $n(770) $n(771) $linkBW 440ms DropTail
	$ns duplex-link $n(772) $n(773) $linkBW 60ms DropTail
	$ns duplex-link $n(772) $n(774) $linkBW 410ms DropTail
	$ns duplex-link $n(772) $n(775) $linkBW 510ms DropTail
	if {$verbose} { puts -nonewline "1600..."; flush stdout }
	$ns duplex-link $n(772) $n(776) $linkBW 270ms DropTail
	$ns duplex-link $n(772) $n(777) $linkBW 310ms DropTail
	$ns duplex-link $n(772) $n(778) $linkBW 700ms DropTail
	$ns duplex-link $n(773) $n(774) $linkBW 360ms DropTail
	$ns duplex-link $n(773) $n(776) $linkBW 280ms DropTail
	$ns duplex-link $n(773) $n(777) $linkBW 270ms DropTail
	$ns duplex-link $n(774) $n(777) $linkBW 130ms DropTail
	$ns duplex-link $n(775) $n(777) $linkBW 510ms DropTail
	$ns duplex-link $n(776) $n(777) $linkBW 200ms DropTail
	$ns duplex-link $n(776) $n(778) $linkBW 430ms DropTail
	if {$verbose} { puts -nonewline "1610..."; flush stdout }
	$ns duplex-link $n(779) $n(781) $linkBW 250ms DropTail
	$ns duplex-link $n(779) $n(783) $linkBW 50ms DropTail
	$ns duplex-link $n(779) $n(784) $linkBW 190ms DropTail
	$ns duplex-link $n(780) $n(781) $linkBW 520ms DropTail
	$ns duplex-link $n(781) $n(783) $linkBW 210ms DropTail
	$ns duplex-link $n(782) $n(783) $linkBW 180ms DropTail
	$ns duplex-link $n(782) $n(784) $linkBW 120ms DropTail
	$ns duplex-link $n(785) $n(787) $linkBW 60ms DropTail
	$ns duplex-link $n(785) $n(788) $linkBW 230ms DropTail
	$ns duplex-link $n(785) $n(790) $linkBW 310ms DropTail
	if {$verbose} { puts -nonewline "1620..."; flush stdout }
	$ns duplex-link $n(785) $n(792) $linkBW 520ms DropTail
	$ns duplex-link $n(785) $n(794) $linkBW 500ms DropTail
	$ns duplex-link $n(786) $n(788) $linkBW 240ms DropTail
	$ns duplex-link $n(786) $n(790) $linkBW 370ms DropTail
	$ns duplex-link $n(786) $n(791) $linkBW 210ms DropTail
	$ns duplex-link $n(786) $n(794) $linkBW 380ms DropTail
	$ns duplex-link $n(787) $n(793) $linkBW 470ms DropTail
	$ns duplex-link $n(787) $n(794) $linkBW 440ms DropTail
	$ns duplex-link $n(788) $n(789) $linkBW 480ms DropTail
	$ns duplex-link $n(788) $n(791) $linkBW 360ms DropTail
	if {$verbose} { puts -nonewline "1630..."; flush stdout }
	$ns duplex-link $n(788) $n(792) $linkBW 570ms DropTail
	$ns duplex-link $n(788) $n(793) $linkBW 690ms DropTail
	$ns duplex-link $n(788) $n(794) $linkBW 600ms DropTail
	$ns duplex-link $n(789) $n(791) $linkBW 120ms DropTail
	$ns duplex-link $n(789) $n(794) $linkBW 210ms DropTail
	$ns duplex-link $n(790) $n(792) $linkBW 370ms DropTail
	$ns duplex-link $n(791) $n(794) $linkBW 270ms DropTail
	$ns duplex-link $n(792) $n(793) $linkBW 320ms DropTail
	$ns duplex-link $n(792) $n(794) $linkBW 120ms DropTail
	$ns duplex-link $n(795) $n(796) $linkBW 50ms DropTail
	if {$verbose} { puts -nonewline "1640..."; flush stdout }
	$ns duplex-link $n(795) $n(797) $linkBW 490ms DropTail
	$ns duplex-link $n(795) $n(798) $linkBW 330ms DropTail
	$ns duplex-link $n(796) $n(797) $linkBW 440ms DropTail
	$ns duplex-link $n(796) $n(799) $linkBW 190ms DropTail
	$ns duplex-link $n(796) $n(800) $linkBW 510ms DropTail
	$ns duplex-link $n(797) $n(799) $linkBW 550ms DropTail
	$ns duplex-link $n(797) $n(800) $linkBW 280ms DropTail
	$ns duplex-link $n(798) $n(799) $linkBW 500ms DropTail
	$ns duplex-link $n(798) $n(800) $linkBW 320ms DropTail
	$ns duplex-link $n(799) $n(800) $linkBW 680ms DropTail
	if {$verbose} { puts -nonewline "1650..."; flush stdout }
	$ns duplex-link $n(801) $n(803) $linkBW 430ms DropTail
	$ns duplex-link $n(801) $n(804) $linkBW 80ms DropTail
	$ns duplex-link $n(801) $n(807) $linkBW 450ms DropTail
	$ns duplex-link $n(801) $n(808) $linkBW 200ms DropTail
	$ns duplex-link $n(801) $n(809) $linkBW 480ms DropTail
	$ns duplex-link $n(802) $n(807) $linkBW 430ms DropTail
	$ns duplex-link $n(803) $n(804) $linkBW 470ms DropTail
	$ns duplex-link $n(803) $n(805) $linkBW 190ms DropTail
	$ns duplex-link $n(803) $n(806) $linkBW 200ms DropTail
	$ns duplex-link $n(803) $n(807) $linkBW 170ms DropTail
	if {$verbose} { puts -nonewline "1660..."; flush stdout }
	$ns duplex-link $n(803) $n(808) $linkBW 240ms DropTail
	$ns duplex-link $n(803) $n(809) $linkBW 210ms DropTail
	$ns duplex-link $n(804) $n(806) $linkBW 340ms DropTail
	$ns duplex-link $n(804) $n(807) $linkBW 510ms DropTail
	$ns duplex-link $n(805) $n(806) $linkBW 100ms DropTail
	$ns duplex-link $n(806) $n(808) $linkBW 210ms DropTail
	$ns duplex-link $n(806) $n(809) $linkBW 150ms DropTail
	$ns duplex-link $n(808) $n(809) $linkBW 340ms DropTail
	$ns duplex-link $n(810) $n(812) $linkBW 330ms DropTail
	$ns duplex-link $n(810) $n(814) $linkBW 460ms DropTail
	if {$verbose} { puts -nonewline "1670..."; flush stdout }
	$ns duplex-link $n(810) $n(816) $linkBW 530ms DropTail
	$ns duplex-link $n(811) $n(812) $linkBW 440ms DropTail
	$ns duplex-link $n(811) $n(814) $linkBW 500ms DropTail
	$ns duplex-link $n(812) $n(813) $linkBW 210ms DropTail
	$ns duplex-link $n(813) $n(815) $linkBW 130ms DropTail
	$ns duplex-link $n(813) $n(816) $linkBW 470ms DropTail
	$ns duplex-link $n(814) $n(815) $linkBW 310ms DropTail
	$ns duplex-link $n(814) $n(816) $linkBW 150ms DropTail
	$ns duplex-link $n(815) $n(816) $linkBW 340ms DropTail
	$ns duplex-link $n(817) $n(818) $linkBW 170ms DropTail
	if {$verbose} { puts -nonewline "1680..."; flush stdout }
	$ns duplex-link $n(817) $n(821) $linkBW 180ms DropTail
	$ns duplex-link $n(817) $n(822) $linkBW 210ms DropTail
	$ns duplex-link $n(817) $n(823) $linkBW 500ms DropTail
	$ns duplex-link $n(817) $n(824) $linkBW 220ms DropTail
	$ns duplex-link $n(818) $n(822) $linkBW 380ms DropTail
	$ns duplex-link $n(818) $n(823) $linkBW 640ms DropTail
	$ns duplex-link $n(819) $n(820) $linkBW 170ms DropTail
	$ns duplex-link $n(819) $n(821) $linkBW 210ms DropTail
	$ns duplex-link $n(819) $n(824) $linkBW 350ms DropTail
	$ns duplex-link $n(820) $n(821) $linkBW 110ms DropTail
	if {$verbose} { puts -nonewline "1690..."; flush stdout }
	$ns duplex-link $n(821) $n(822) $linkBW 50ms DropTail
	$ns duplex-link $n(821) $n(823) $linkBW 310ms DropTail
	$ns duplex-link $n(821) $n(824) $linkBW 150ms DropTail
	$ns duplex-link $n(823) $n(824) $linkBW 390ms DropTail
	$ns duplex-link $n(825) $n(834) $linkBW 70ms DropTail
	$ns duplex-link $n(825) $n(826) $linkBW 180ms DropTail
	$ns duplex-link $n(825) $n(830) $linkBW 190ms DropTail
	$ns duplex-link $n(825) $n(831) $linkBW 150ms DropTail
	$ns duplex-link $n(826) $n(844) $linkBW 270ms DropTail
	$ns duplex-link $n(826) $n(828) $linkBW 160ms DropTail
	if {$verbose} { puts -nonewline "1700..."; flush stdout }
	$ns duplex-link $n(826) $n(829) $linkBW 190ms DropTail
	$ns duplex-link $n(826) $n(830) $linkBW 370ms DropTail
	$ns duplex-link $n(827) $n(862) $linkBW 280ms DropTail
	$ns duplex-link $n(827) $n(852) $linkBW 270ms DropTail
	$ns duplex-link $n(827) $n(830) $linkBW 130ms DropTail
	$ns duplex-link $n(828) $n(903) $linkBW 350ms DropTail
	$ns duplex-link $n(828) $n(885) $linkBW 410ms DropTail
	$ns duplex-link $n(828) $n(881) $linkBW 100ms DropTail
	$ns duplex-link $n(828) $n(874) $linkBW 150ms DropTail
	$ns duplex-link $n(828) $n(864) $linkBW 380ms DropTail
	if {$verbose} { puts -nonewline "1710..."; flush stdout }
	$ns duplex-link $n(828) $n(830) $linkBW 280ms DropTail
	$ns duplex-link $n(829) $n(931) $linkBW 360ms DropTail
	$ns duplex-link $n(829) $n(924) $linkBW 410ms DropTail
	$ns duplex-link $n(829) $n(915) $linkBW 230ms DropTail
	$ns duplex-link $n(829) $n(907) $linkBW 20ms DropTail
	$ns duplex-link $n(829) $n(830) $linkBW 430ms DropTail
	$ns duplex-link $n(829) $n(831) $linkBW 230ms DropTail
	$ns duplex-link $n(830) $n(955) $linkBW 290ms DropTail
	$ns duplex-link $n(830) $n(954) $linkBW 240ms DropTail
	$ns duplex-link $n(830) $n(936) $linkBW 370ms DropTail
	if {$verbose} { puts -nonewline "1720..."; flush stdout }
	$ns duplex-link $n(831) $n(997) $linkBW 330ms DropTail
	$ns duplex-link $n(831) $n(992) $linkBW 360ms DropTail
	$ns duplex-link $n(831) $n(980) $linkBW 430ms DropTail
	$ns duplex-link $n(831) $n(975) $linkBW 190ms DropTail
	$ns duplex-link $n(831) $n(960) $linkBW 460ms DropTail
	$ns duplex-link $n(832) $n(834) $linkBW 320ms DropTail
	$ns duplex-link $n(832) $n(836) $linkBW 70ms DropTail
	$ns duplex-link $n(832) $n(837) $linkBW 490ms DropTail
	$ns duplex-link $n(832) $n(839) $linkBW 60ms DropTail
	$ns duplex-link $n(833) $n(834) $linkBW 90ms DropTail
	if {$verbose} { puts -nonewline "1730..."; flush stdout }
	$ns duplex-link $n(833) $n(835) $linkBW 420ms DropTail
	$ns duplex-link $n(833) $n(836) $linkBW 420ms DropTail
	$ns duplex-link $n(833) $n(839) $linkBW 430ms DropTail
	$ns duplex-link $n(834) $n(835) $linkBW 350ms DropTail
	$ns duplex-link $n(834) $n(836) $linkBW 340ms DropTail
	$ns duplex-link $n(834) $n(838) $linkBW 260ms DropTail
	$ns duplex-link $n(835) $n(837) $linkBW 570ms DropTail
	$ns duplex-link $n(835) $n(839) $linkBW 170ms DropTail
	$ns duplex-link $n(836) $n(837) $linkBW 460ms DropTail
	$ns duplex-link $n(836) $n(838) $linkBW 170ms DropTail
	if {$verbose} { puts -nonewline "1740..."; flush stdout }
	$ns duplex-link $n(838) $n(839) $linkBW 180ms DropTail
	$ns duplex-link $n(840) $n(841) $linkBW 310ms DropTail
	$ns duplex-link $n(840) $n(842) $linkBW 270ms DropTail
	$ns duplex-link $n(840) $n(846) $linkBW 240ms DropTail
	$ns duplex-link $n(840) $n(847) $linkBW 50ms DropTail
	$ns duplex-link $n(841) $n(842) $linkBW 70ms DropTail
	$ns duplex-link $n(841) $n(844) $linkBW 280ms DropTail
	$ns duplex-link $n(841) $n(847) $linkBW 330ms DropTail
	$ns duplex-link $n(842) $n(845) $linkBW 90ms DropTail
	$ns duplex-link $n(842) $n(847) $linkBW 290ms DropTail
	if {$verbose} { puts -nonewline "1750..."; flush stdout }
	$ns duplex-link $n(843) $n(845) $linkBW 330ms DropTail
	$ns duplex-link $n(843) $n(846) $linkBW 570ms DropTail
	$ns duplex-link $n(843) $n(847) $linkBW 460ms DropTail
	$ns duplex-link $n(844) $n(845) $linkBW 160ms DropTail
	$ns duplex-link $n(845) $n(847) $linkBW 190ms DropTail
	$ns duplex-link $n(848) $n(849) $linkBW 260ms DropTail
	$ns duplex-link $n(848) $n(852) $linkBW 270ms DropTail
	$ns duplex-link $n(848) $n(853) $linkBW 120ms DropTail
	$ns duplex-link $n(848) $n(854) $linkBW 460ms DropTail
	$ns duplex-link $n(849) $n(850) $linkBW 490ms DropTail
	if {$verbose} { puts -nonewline "1760..."; flush stdout }
	$ns duplex-link $n(849) $n(851) $linkBW 340ms DropTail
	$ns duplex-link $n(850) $n(852) $linkBW 150ms DropTail
	$ns duplex-link $n(850) $n(854) $linkBW 70ms DropTail
	$ns duplex-link $n(851) $n(854) $linkBW 180ms DropTail
	$ns duplex-link $n(852) $n(853) $linkBW 380ms DropTail
	$ns duplex-link $n(853) $n(854) $linkBW 560ms DropTail
	$ns duplex-link $n(855) $n(857) $linkBW 350ms DropTail
	$ns duplex-link $n(855) $n(858) $linkBW 610ms DropTail
	$ns duplex-link $n(855) $n(859) $linkBW 450ms DropTail
	$ns duplex-link $n(855) $n(861) $linkBW 490ms DropTail
	if {$verbose} { puts -nonewline "1770..."; flush stdout }
	$ns duplex-link $n(855) $n(863) $linkBW 400ms DropTail
	$ns duplex-link $n(856) $n(857) $linkBW 450ms DropTail
	$ns duplex-link $n(856) $n(860) $linkBW 280ms DropTail
	$ns duplex-link $n(856) $n(861) $linkBW 230ms DropTail
	$ns duplex-link $n(856) $n(863) $linkBW 300ms DropTail
	$ns duplex-link $n(857) $n(858) $linkBW 370ms DropTail
	$ns duplex-link $n(857) $n(859) $linkBW 240ms DropTail
	$ns duplex-link $n(858) $n(861) $linkBW 150ms DropTail
	$ns duplex-link $n(859) $n(860) $linkBW 50ms DropTail
	$ns duplex-link $n(859) $n(863) $linkBW 60ms DropTail
	if {$verbose} { puts -nonewline "1780..."; flush stdout }
	$ns duplex-link $n(860) $n(862) $linkBW 110ms DropTail
	$ns duplex-link $n(860) $n(863) $linkBW 40ms DropTail
	$ns duplex-link $n(861) $n(862) $linkBW 180ms DropTail
	$ns duplex-link $n(864) $n(865) $linkBW 320ms DropTail
	$ns duplex-link $n(864) $n(866) $linkBW 170ms DropTail
	$ns duplex-link $n(864) $n(870) $linkBW 190ms DropTail
	$ns duplex-link $n(865) $n(866) $linkBW 380ms DropTail
	$ns duplex-link $n(865) $n(867) $linkBW 300ms DropTail
	$ns duplex-link $n(865) $n(869) $linkBW 170ms DropTail
	$ns duplex-link $n(865) $n(870) $linkBW 330ms DropTail
	if {$verbose} { puts -nonewline "1790..."; flush stdout }
	$ns duplex-link $n(866) $n(868) $linkBW 170ms DropTail
	$ns duplex-link $n(866) $n(870) $linkBW 360ms DropTail
	$ns duplex-link $n(867) $n(868) $linkBW 350ms DropTail
	$ns duplex-link $n(867) $n(869) $linkBW 360ms DropTail
	$ns duplex-link $n(867) $n(870) $linkBW 130ms DropTail
	$ns duplex-link $n(871) $n(875) $linkBW 120ms DropTail
	$ns duplex-link $n(871) $n(876) $linkBW 100ms DropTail
	$ns duplex-link $n(871) $n(877) $linkBW 250ms DropTail
	$ns duplex-link $n(872) $n(874) $linkBW 490ms DropTail
	$ns duplex-link $n(872) $n(875) $linkBW 360ms DropTail
	if {$verbose} { puts -nonewline "1800..."; flush stdout }
	$ns duplex-link $n(872) $n(878) $linkBW 380ms DropTail
	$ns duplex-link $n(873) $n(874) $linkBW 450ms DropTail
	$ns duplex-link $n(873) $n(877) $linkBW 470ms DropTail
	$ns duplex-link $n(873) $n(878) $linkBW 270ms DropTail
	$ns duplex-link $n(873) $n(879) $linkBW 340ms DropTail
	$ns duplex-link $n(873) $n(880) $linkBW 320ms DropTail
	$ns duplex-link $n(874) $n(876) $linkBW 200ms DropTail
	$ns duplex-link $n(874) $n(879) $linkBW 310ms DropTail
	$ns duplex-link $n(874) $n(880) $linkBW 130ms DropTail
	$ns duplex-link $n(875) $n(876) $linkBW 170ms DropTail
	if {$verbose} { puts -nonewline "1810..."; flush stdout }
	$ns duplex-link $n(875) $n(877) $linkBW 360ms DropTail
	$ns duplex-link $n(875) $n(880) $linkBW 340ms DropTail
	$ns duplex-link $n(876) $n(877) $linkBW 200ms DropTail
	$ns duplex-link $n(876) $n(878) $linkBW 480ms DropTail
	$ns duplex-link $n(876) $n(880) $linkBW 230ms DropTail
	$ns duplex-link $n(877) $n(878) $linkBW 400ms DropTail
	$ns duplex-link $n(877) $n(879) $linkBW 320ms DropTail
	$ns duplex-link $n(877) $n(880) $linkBW 160ms DropTail
	$ns duplex-link $n(878) $n(879) $linkBW 470ms DropTail
	$ns duplex-link $n(879) $n(880) $linkBW 280ms DropTail
	if {$verbose} { puts -nonewline "1820..."; flush stdout }
	$ns duplex-link $n(881) $n(882) $linkBW 440ms DropTail
	$ns duplex-link $n(883) $n(885) $linkBW 10ms DropTail
	$ns duplex-link $n(883) $n(886) $linkBW 90ms DropTail
	$ns duplex-link $n(883) $n(887) $linkBW 400ms DropTail
	$ns duplex-link $n(883) $n(889) $linkBW 370ms DropTail
	$ns duplex-link $n(883) $n(891) $linkBW 190ms DropTail
	$ns duplex-link $n(883) $n(892) $linkBW 220ms DropTail
	$ns duplex-link $n(883) $n(894) $linkBW 340ms DropTail
	$ns duplex-link $n(884) $n(888) $linkBW 540ms DropTail
	$ns duplex-link $n(884) $n(890) $linkBW 440ms DropTail
	if {$verbose} { puts -nonewline "1830..."; flush stdout }
	$ns duplex-link $n(884) $n(892) $linkBW 550ms DropTail
	$ns duplex-link $n(884) $n(894) $linkBW 190ms DropTail
	$ns duplex-link $n(884) $n(895) $linkBW 440ms DropTail
	$ns duplex-link $n(885) $n(886) $linkBW 80ms DropTail
	$ns duplex-link $n(885) $n(887) $linkBW 410ms DropTail
	$ns duplex-link $n(885) $n(889) $linkBW 380ms DropTail
	$ns duplex-link $n(885) $n(892) $linkBW 220ms DropTail
	$ns duplex-link $n(885) $n(895) $linkBW 180ms DropTail
	$ns duplex-link $n(886) $n(887) $linkBW 490ms DropTail
	$ns duplex-link $n(886) $n(889) $linkBW 460ms DropTail
	if {$verbose} { puts -nonewline "1840..."; flush stdout }
	$ns duplex-link $n(886) $n(890) $linkBW 280ms DropTail
	$ns duplex-link $n(886) $n(891) $linkBW 260ms DropTail
	$ns duplex-link $n(886) $n(894) $linkBW 420ms DropTail
	$ns duplex-link $n(887) $n(888) $linkBW 400ms DropTail
	$ns duplex-link $n(887) $n(889) $linkBW 30ms DropTail
	$ns duplex-link $n(887) $n(892) $linkBW 380ms DropTail
	$ns duplex-link $n(888) $n(890) $linkBW 380ms DropTail
	$ns duplex-link $n(888) $n(892) $linkBW 120ms DropTail
	$ns duplex-link $n(888) $n(895) $linkBW 130ms DropTail
	$ns duplex-link $n(889) $n(890) $linkBW 420ms DropTail
	if {$verbose} { puts -nonewline "1850..."; flush stdout }
	$ns duplex-link $n(889) $n(891) $linkBW 220ms DropTail
	$ns duplex-link $n(889) $n(892) $linkBW 350ms DropTail
	$ns duplex-link $n(889) $n(894) $linkBW 60ms DropTail
	$ns duplex-link $n(890) $n(892) $linkBW 480ms DropTail
	$ns duplex-link $n(890) $n(895) $linkBW 380ms DropTail
	$ns duplex-link $n(891) $n(892) $linkBW 310ms DropTail
	$ns duplex-link $n(891) $n(895) $linkBW 190ms DropTail
	$ns duplex-link $n(892) $n(893) $linkBW 200ms DropTail
	$ns duplex-link $n(892) $n(894) $linkBW 360ms DropTail
	$ns duplex-link $n(894) $n(895) $linkBW 240ms DropTail
	if {$verbose} { puts -nonewline "1860..."; flush stdout }
	$ns duplex-link $n(896) $n(897) $linkBW 70ms DropTail
	$ns duplex-link $n(896) $n(899) $linkBW 130ms DropTail
	$ns duplex-link $n(896) $n(900) $linkBW 420ms DropTail
	$ns duplex-link $n(896) $n(901) $linkBW 340ms DropTail
	$ns duplex-link $n(896) $n(903) $linkBW 280ms DropTail
	$ns duplex-link $n(897) $n(901) $linkBW 410ms DropTail
	$ns duplex-link $n(897) $n(902) $linkBW 220ms DropTail
	$ns duplex-link $n(897) $n(903) $linkBW 350ms DropTail
	$ns duplex-link $n(898) $n(900) $linkBW 410ms DropTail
	$ns duplex-link $n(898) $n(902) $linkBW 170ms DropTail
	if {$verbose} { puts -nonewline "1870..."; flush stdout }
	$ns duplex-link $n(898) $n(903) $linkBW 410ms DropTail
	$ns duplex-link $n(899) $n(900) $linkBW 520ms DropTail
	$ns duplex-link $n(900) $n(901) $linkBW 210ms DropTail
	$ns duplex-link $n(900) $n(902) $linkBW 570ms DropTail
	$ns duplex-link $n(901) $n(902) $linkBW 580ms DropTail
	$ns duplex-link $n(902) $n(903) $linkBW 550ms DropTail
	$ns duplex-link $n(904) $n(907) $linkBW 300ms DropTail
	$ns duplex-link $n(904) $n(911) $linkBW 300ms DropTail
	$ns duplex-link $n(905) $n(907) $linkBW 500ms DropTail
	$ns duplex-link $n(905) $n(908) $linkBW 240ms DropTail
	if {$verbose} { puts -nonewline "1880..."; flush stdout }
	$ns duplex-link $n(905) $n(910) $linkBW 80ms DropTail
	$ns duplex-link $n(906) $n(907) $linkBW 490ms DropTail
	$ns duplex-link $n(906) $n(909) $linkBW 370ms DropTail
	$ns duplex-link $n(906) $n(910) $linkBW 250ms DropTail
	$ns duplex-link $n(906) $n(911) $linkBW 50ms DropTail
	$ns duplex-link $n(906) $n(912) $linkBW 120ms DropTail
	$ns duplex-link $n(907) $n(908) $linkBW 460ms DropTail
	$ns duplex-link $n(907) $n(909) $linkBW 180ms DropTail
	$ns duplex-link $n(907) $n(910) $linkBW 570ms DropTail
	$ns duplex-link $n(907) $n(911) $linkBW 470ms DropTail
	if {$verbose} { puts -nonewline "1890..."; flush stdout }
	$ns duplex-link $n(907) $n(912) $linkBW 430ms DropTail
	$ns duplex-link $n(908) $n(909) $linkBW 370ms DropTail
	$ns duplex-link $n(908) $n(912) $linkBW 170ms DropTail
	$ns duplex-link $n(909) $n(910) $linkBW 400ms DropTail
	$ns duplex-link $n(910) $n(912) $linkBW 180ms DropTail
	$ns duplex-link $n(911) $n(912) $linkBW 160ms DropTail
	$ns duplex-link $n(913) $n(914) $linkBW 230ms DropTail
	$ns duplex-link $n(914) $n(917) $linkBW 90ms DropTail
	$ns duplex-link $n(915) $n(917) $linkBW 170ms DropTail
	$ns duplex-link $n(915) $n(918) $linkBW 200ms DropTail
	if {$verbose} { puts -nonewline "1900..."; flush stdout }
	$ns duplex-link $n(916) $n(917) $linkBW 160ms DropTail
	$ns duplex-link $n(919) $n(923) $linkBW 480ms DropTail
	$ns duplex-link $n(919) $n(925) $linkBW 300ms DropTail
	$ns duplex-link $n(920) $n(921) $linkBW 420ms DropTail
	$ns duplex-link $n(921) $n(923) $linkBW 290ms DropTail
	$ns duplex-link $n(922) $n(925) $linkBW 440ms DropTail
	$ns duplex-link $n(923) $n(924) $linkBW 580ms DropTail
	$ns duplex-link $n(926) $n(929) $linkBW 140ms DropTail
	$ns duplex-link $n(926) $n(930) $linkBW 310ms DropTail
	$ns duplex-link $n(926) $n(932) $linkBW 310ms DropTail
	if {$verbose} { puts -nonewline "1910..."; flush stdout }
	$ns duplex-link $n(926) $n(933) $linkBW 420ms DropTail
	$ns duplex-link $n(926) $n(934) $linkBW 220ms DropTail
	$ns duplex-link $n(926) $n(935) $linkBW 180ms DropTail
	$ns duplex-link $n(927) $n(930) $linkBW 160ms DropTail
	$ns duplex-link $n(927) $n(932) $linkBW 190ms DropTail
	$ns duplex-link $n(927) $n(933) $linkBW 80ms DropTail
	$ns duplex-link $n(927) $n(935) $linkBW 400ms DropTail
	$ns duplex-link $n(928) $n(929) $linkBW 20ms DropTail
	$ns duplex-link $n(928) $n(930) $linkBW 210ms DropTail
	$ns duplex-link $n(928) $n(931) $linkBW 400ms DropTail
	if {$verbose} { puts -nonewline "1920..."; flush stdout }
	$ns duplex-link $n(928) $n(934) $linkBW 120ms DropTail
	$ns duplex-link $n(929) $n(930) $linkBW 220ms DropTail
	$ns duplex-link $n(931) $n(932) $linkBW 230ms DropTail
	$ns duplex-link $n(931) $n(933) $linkBW 210ms DropTail
	$ns duplex-link $n(931) $n(935) $linkBW 450ms DropTail
	$ns duplex-link $n(933) $n(934) $linkBW 230ms DropTail
	$ns duplex-link $n(933) $n(935) $linkBW 430ms DropTail
	$ns duplex-link $n(934) $n(935) $linkBW 210ms DropTail
	$ns duplex-link $n(936) $n(938) $linkBW 130ms DropTail
	$ns duplex-link $n(936) $n(940) $linkBW 170ms DropTail
	if {$verbose} { puts -nonewline "1930..."; flush stdout }
	$ns duplex-link $n(936) $n(941) $linkBW 130ms DropTail
	$ns duplex-link $n(936) $n(943) $linkBW 490ms DropTail
	$ns duplex-link $n(936) $n(944) $linkBW 470ms DropTail
	$ns duplex-link $n(937) $n(938) $linkBW 150ms DropTail
	$ns duplex-link $n(937) $n(939) $linkBW 350ms DropTail
	$ns duplex-link $n(937) $n(943) $linkBW 470ms DropTail
	$ns duplex-link $n(938) $n(940) $linkBW 190ms DropTail
	$ns duplex-link $n(938) $n(943) $linkBW 380ms DropTail
	$ns duplex-link $n(939) $n(941) $linkBW 390ms DropTail
	$ns duplex-link $n(940) $n(944) $linkBW 380ms DropTail
	if {$verbose} { puts -nonewline "1940..."; flush stdout }
	$ns duplex-link $n(941) $n(942) $linkBW 260ms DropTail
	$ns duplex-link $n(941) $n(943) $linkBW 500ms DropTail
	$ns duplex-link $n(941) $n(944) $linkBW 450ms DropTail
	$ns duplex-link $n(942) $n(944) $linkBW 400ms DropTail
	$ns duplex-link $n(943) $n(944) $linkBW 110ms DropTail
	$ns duplex-link $n(945) $n(946) $linkBW 280ms DropTail
	$ns duplex-link $n(945) $n(947) $linkBW 210ms DropTail
	$ns duplex-link $n(945) $n(948) $linkBW 460ms DropTail
	$ns duplex-link $n(945) $n(953) $linkBW 70ms DropTail
	$ns duplex-link $n(946) $n(947) $linkBW 270ms DropTail
	if {$verbose} { puts -nonewline "1950..."; flush stdout }
	$ns duplex-link $n(946) $n(948) $linkBW 440ms DropTail
	$ns duplex-link $n(946) $n(950) $linkBW 110ms DropTail
	$ns duplex-link $n(946) $n(951) $linkBW 110ms DropTail
	$ns duplex-link $n(946) $n(953) $linkBW 310ms DropTail
	$ns duplex-link $n(947) $n(949) $linkBW 450ms DropTail
	$ns duplex-link $n(947) $n(950) $linkBW 200ms DropTail
	$ns duplex-link $n(947) $n(954) $linkBW 300ms DropTail
	$ns duplex-link $n(948) $n(953) $linkBW 420ms DropTail
	$ns duplex-link $n(948) $n(954) $linkBW 490ms DropTail
	$ns duplex-link $n(949) $n(950) $linkBW 270ms DropTail
	if {$verbose} { puts -nonewline "1960..."; flush stdout }
	$ns duplex-link $n(949) $n(952) $linkBW 310ms DropTail
	$ns duplex-link $n(949) $n(953) $linkBW 340ms DropTail
	$ns duplex-link $n(950) $n(951) $linkBW 230ms DropTail
	$ns duplex-link $n(950) $n(952) $linkBW 250ms DropTail
	$ns duplex-link $n(952) $n(953) $linkBW 80ms DropTail
	$ns duplex-link $n(953) $n(954) $linkBW 300ms DropTail
	$ns duplex-link $n(955) $n(957) $linkBW 180ms DropTail
	$ns duplex-link $n(955) $n(958) $linkBW 110ms DropTail
	$ns duplex-link $n(956) $n(957) $linkBW 210ms DropTail
	$ns duplex-link $n(956) $n(958) $linkBW 280ms DropTail
	if {$verbose} { puts -nonewline "1970..."; flush stdout }
	$ns duplex-link $n(956) $n(959) $linkBW 60ms DropTail
	$ns duplex-link $n(958) $n(959) $linkBW 300ms DropTail
	$ns duplex-link $n(960) $n(963) $linkBW 300ms DropTail
	$ns duplex-link $n(960) $n(964) $linkBW 270ms DropTail
	$ns duplex-link $n(960) $n(967) $linkBW 350ms DropTail
	$ns duplex-link $n(960) $n(968) $linkBW 120ms DropTail
	$ns duplex-link $n(960) $n(969) $linkBW 120ms DropTail
	$ns duplex-link $n(961) $n(962) $linkBW 130ms DropTail
	$ns duplex-link $n(961) $n(963) $linkBW 120ms DropTail
	$ns duplex-link $n(961) $n(966) $linkBW 180ms DropTail
	if {$verbose} { puts -nonewline "1980..."; flush stdout }
	$ns duplex-link $n(961) $n(968) $linkBW 310ms DropTail
	$ns duplex-link $n(962) $n(963) $linkBW 240ms DropTail
	$ns duplex-link $n(962) $n(964) $linkBW 400ms DropTail
	$ns duplex-link $n(962) $n(965) $linkBW 220ms DropTail
	$ns duplex-link $n(962) $n(967) $linkBW 320ms DropTail
	$ns duplex-link $n(962) $n(968) $linkBW 200ms DropTail
	$ns duplex-link $n(962) $n(969) $linkBW 290ms DropTail
	$ns duplex-link $n(963) $n(965) $linkBW 430ms DropTail
	$ns duplex-link $n(963) $n(966) $linkBW 180ms DropTail
	$ns duplex-link $n(963) $n(968) $linkBW 380ms DropTail
	if {$verbose} { puts -nonewline "1990..."; flush stdout }
	$ns duplex-link $n(963) $n(969) $linkBW 300ms DropTail
	$ns duplex-link $n(964) $n(968) $linkBW 380ms DropTail
	$ns duplex-link $n(964) $n(970) $linkBW 380ms DropTail
	$ns duplex-link $n(965) $n(967) $linkBW 500ms DropTail
	$ns duplex-link $n(965) $n(969) $linkBW 310ms DropTail
	$ns duplex-link $n(965) $n(970) $linkBW 300ms DropTail
	$ns duplex-link $n(966) $n(967) $linkBW 210ms DropTail
	$ns duplex-link $n(966) $n(969) $linkBW 470ms DropTail
	$ns duplex-link $n(966) $n(970) $linkBW 220ms DropTail
	$ns duplex-link $n(967) $n(969) $linkBW 330ms DropTail
	if {$verbose} { puts -nonewline "2000..."; flush stdout }
	$ns duplex-link $n(968) $n(969) $linkBW 230ms DropTail
	$ns duplex-link $n(971) $n(972) $linkBW 390ms DropTail
	$ns duplex-link $n(971) $n(975) $linkBW 320ms DropTail
	$ns duplex-link $n(972) $n(973) $linkBW 320ms DropTail
	$ns duplex-link $n(973) $n(974) $linkBW 420ms DropTail
	$ns duplex-link $n(974) $n(976) $linkBW 430ms DropTail
	$ns duplex-link $n(975) $n(977) $linkBW 220ms DropTail
	$ns duplex-link $n(978) $n(981) $linkBW 570ms DropTail
	$ns duplex-link $n(978) $n(982) $linkBW 590ms DropTail
	$ns duplex-link $n(978) $n(983) $linkBW 460ms DropTail
	if {$verbose} { puts -nonewline "2010..."; flush stdout }
	$ns duplex-link $n(978) $n(984) $linkBW 300ms DropTail
	$ns duplex-link $n(979) $n(980) $linkBW 280ms DropTail
	$ns duplex-link $n(979) $n(982) $linkBW 400ms DropTail
	$ns duplex-link $n(980) $n(982) $linkBW 430ms DropTail
	$ns duplex-link $n(980) $n(984) $linkBW 210ms DropTail
	$ns duplex-link $n(981) $n(983) $linkBW 140ms DropTail
	$ns duplex-link $n(981) $n(984) $linkBW 390ms DropTail
	$ns duplex-link $n(982) $n(983) $linkBW 260ms DropTail
	$ns duplex-link $n(982) $n(984) $linkBW 330ms DropTail
	$ns duplex-link $n(984) $n(985) $linkBW 150ms DropTail
	if {$verbose} { puts -nonewline "2020..."; flush stdout }
	$ns duplex-link $n(986) $n(987) $linkBW 200ms DropTail
	$ns duplex-link $n(986) $n(988) $linkBW 390ms DropTail
	$ns duplex-link $n(986) $n(989) $linkBW 680ms DropTail
	$ns duplex-link $n(986) $n(992) $linkBW 490ms DropTail
	$ns duplex-link $n(987) $n(988) $linkBW 300ms DropTail
	$ns duplex-link $n(987) $n(990) $linkBW 430ms DropTail
	$ns duplex-link $n(987) $n(992) $linkBW 290ms DropTail
	$ns duplex-link $n(988) $n(989) $linkBW 430ms DropTail
	$ns duplex-link $n(988) $n(990) $linkBW 260ms DropTail
	$ns duplex-link $n(988) $n(991) $linkBW 150ms DropTail
	if {$verbose} { puts -nonewline "2030..."; flush stdout }
	$ns duplex-link $n(988) $n(992) $linkBW 460ms DropTail
	$ns duplex-link $n(989) $n(990) $linkBW 200ms DropTail
	$ns duplex-link $n(989) $n(992) $linkBW 320ms DropTail
	$ns duplex-link $n(990) $n(991) $linkBW 220ms DropTail
	$ns duplex-link $n(990) $n(992) $linkBW 390ms DropTail
	$ns duplex-link $n(993) $n(994) $linkBW 180ms DropTail
	$ns duplex-link $n(993) $n(995) $linkBW 530ms DropTail
	$ns duplex-link $n(993) $n(996) $linkBW 210ms DropTail
	$ns duplex-link $n(993) $n(998) $linkBW 430ms DropTail
	$ns duplex-link $n(994) $n(998) $linkBW 390ms DropTail
	if {$verbose} { puts -nonewline "2040..."; flush stdout }
	$ns duplex-link $n(994) $n(999) $linkBW 280ms DropTail
	$ns duplex-link $n(995) $n(996) $linkBW 330ms DropTail
	$ns duplex-link $n(995) $n(997) $linkBW 310ms DropTail
	$ns duplex-link $n(995) $n(998) $linkBW 400ms DropTail
	$ns duplex-link $n(996) $n(997) $linkBW 520ms DropTail
	$ns duplex-link $n(996) $n(998) $linkBW 370ms DropTail
	$ns duplex-link $n(996) $n(999) $linkBW 260ms DropTail
	$ns duplex-link $n(997) $n(999) $linkBW 350ms DropTail

	if {$verbose} { 
		puts -nonewline "2048..."
		flush stdout
		puts "starting"
	}
	return 1000}
